@@ -46,12 +46,16 @@ typedef enum
 }
 zbx_async_resolve_reverse_dns_t;
 
-typedef int (*zbx_async_task_process_cb_t)(short event, void *data, int *fd, const char *addr, char *dnserr);
+typedef int (*zbx_async_task_process_cb_t)(short event, void *data, int *fd, const char *addr, char *dnserr,
+		struct event *timeout_event);
 typedef void (*zbx_async_task_clear_cb_t)(void *data);
 
 zbx_async_task_state_t	zbx_async_poller_get_task_state_for_event(short event);
 void			zbx_async_poller_add_task(struct event_base *ev, struct evdns_base *dnsbase, const char *addr,
 		void *data, int timeout, zbx_async_task_process_cb_t process_cb, zbx_async_task_clear_cb_t clear_cb);
 const char		*zbx_resolv_conf_errstr(int error);
+const char		*zbx_get_event_string(short event);
+const char		*zbx_task_state_to_str(zbx_async_task_state_t task_state);
+void			zbx_async_dns_update_host_addresses(struct evdns_base *dnsbase);
 #endif
 #endif
