@@ -33,8 +33,6 @@
 #define ZBX_RETRIEVE_MODE_BOTH		2
 
 int	zbx_http_punycode_encode_url(char **url);
-void	zbx_http_url_encode(const char *source, char **result);
-int	zbx_http_url_decode(const char *source, char **result);
 char	*zbx_determine_charset(const char *content_type, char *body, size_t size);
 
 #ifdef HAVE_LIBCURL
@@ -76,10 +74,10 @@ int	zbx_http_prepare_auth(CURL *easyhandle, unsigned char authtype, const char *
 		const char *token, char **error);
 char	*zbx_http_parse_header(char **headers);
 
-int	zbx_http_get(const char *url, const char *header, long timeout, const char *ssl_cert_file,
+int	zbx_http_req(const char *url, const char *header, long timeout, const char *ssl_cert_file,
 		const char *ssl_key_file, const char *config_source_ip, const char *config_ssl_ca_location,
 		const char *config_ssl_cert_location, const char *config_ssl_key_location, char **out,
-		long *response_code, char **error);
+		const char *post_data, long *response_code, char **error);
 
 #define HTTP_REQUEST_GET	0
 #define HTTP_REQUEST_POST	1
@@ -91,7 +89,8 @@ int	zbx_http_get(const char *url, const char *header, long timeout, const char *
 
 void	zbx_http_context_create(zbx_http_context_t *context);
 void	zbx_http_context_destroy(zbx_http_context_t *context);
-int	zbx_http_request_prepare(zbx_http_context_t *context, unsigned char request_method, const char *url, const char *query_fields, char *headers,
+int	zbx_http_request_prepare(zbx_http_context_t *context, unsigned char request_method, const char *url,
+		const char *query_fields, char *headers,
 		const char *posts, unsigned char retrieve_mode, const char *http_proxy, unsigned char follow_redirects,
 		int timeout, int max_attempts, const char *ssl_cert_file, const char *ssl_key_file,
 		const char *ssl_key_password, unsigned char verify_peer, unsigned char verify_host,
