@@ -215,6 +215,8 @@
 #define ZBX_PROTO_TAG_DEL_HOSTPROXYIDS		"del_hostproxyids"
 #define ZBX_PROTO_TAG_RESET			"reset"
 #define ZBX_PROTO_TAG_VARIANT			"variant"
+#define ZBX_PROTO_TAG_AUTH			"auth"
+#define ZBX_PROTO_TAG_LEASE_DURATION		"lease_duration"
 
 #define ZBX_PROTO_VALUE_FAILED		"failed"
 #define ZBX_PROTO_VALUE_SUCCESS		"success"
