@@ -24,6 +24,12 @@
 #define ZBX_IGNORE_CASE		0
 #define ZBX_CASE_SENSITIVE	1
 
+typedef enum {
+	ZBX_REGEXP_GROUP_CHECK_DISABLE,
+	ZBX_REGEXP_GROUP_CHECK_ENABLE
+}
+zbx_regexp_group_check_t;
+
 typedef struct zbx_regexp zbx_regexp_t;
 
 typedef struct
@@ -46,11 +52,12 @@ int	zbx_regexp_match_precompiled(const char *string, const zbx_regexp_t *regexp)
 int	zbx_regexp_match_precompiled2(const char *string, const zbx_regexp_t *regexp, char **err_msg);
 char	*zbx_regexp_match(const char *string, const char *pattern, int *len);
 int	zbx_regexp_sub(const char *string, const char *pattern, const char *output_template, char **out);
-int	zbx_mregexp_sub(const char *string, const char *pattern, const char *output_template, char **out);
+int	zbx_mregexp_sub(const char *string, const char *pattern, const char *output_template,
+		zbx_regexp_group_check_t group_check, char **out);
 int	zbx_iregexp_sub(const char *string, const char *pattern, const char *output_template, char **out);
 int	zbx_mregexp_sub_precompiled(const char *string, const zbx_regexp_t *regexp, const char *output_template,
 		size_t limit, char **out);
-
+int	zbx_regexp_repl(const char *string, const char *pattern, const char *repl_template, char **out);
 void	zbx_regexp_clean_expressions(zbx_vector_expression_t *expressions);
 
 void	zbx_add_regexp_ex(zbx_vector_expression_t *regexps, const char *name, const char *expression,
