@@ -22,13 +22,13 @@ import (
 )
 
 const (
-	ZABBIX_REVDATE          = "21 October 2024"
+	ZABBIX_REVDATE          = "20 November 2024"
 	ZABBIX_VERSION_MAJOR    = 7
 	ZABBIX_VERSION_MINOR    = 0
-	ZABBIX_VERSION_PATCH    = 5
+	ZABBIX_VERSION_PATCH    = 6
 	ZABBIX_VERSION_RC       = ""
 	ZABBIX_VERSION_RC_NUM   = "1400"
-	ZABBIX_VERSION_REVISION = "9406e67a5ff"
+	ZABBIX_VERSION_REVISION = "c1d7a081969"
 	copyrightMessage        = "Copyright (C) 2024 Zabbix SIA\n" +
 		"License AGPLv3: GNU Affero General Public License version 3 <https://www.gnu.org/licenses/>.\n" +
 		"This is free software: you are free to change and redistribute it according to\n" +
