@@ -1,20 +1,15 @@
 /*
-** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 package vfsfs
@@ -23,7 +18,7 @@ import (
 	"encoding/json"
 	"errors"
 
-	"git.zabbix.com/ap/plugin-support/plugin"
+	"golang.zabbix.com/sdk/plugin"
 )
 
 const (
@@ -53,6 +48,7 @@ type FsInfo struct {
 	DriveType  *string  `json:"{#FSDRIVETYPE},omitempty"`
 	Bytes      *FsStats `json:"bytes,omitempty"`
 	Inodes     *FsStats `json:"inodes,omitempty"`
+	FsOptions  *string  `json:"{#FSOPTIONS},omitempty"`
 }
 
 type FsInfoNew struct {
@@ -62,6 +58,7 @@ type FsInfoNew struct {
 	DriveType  *string  `json:"fsdrivetype,omitempty"`
 	Bytes      *FsStats `json:"bytes,omitempty"`
 	Inodes     *FsStats `json:"inodes,omitempty"`
+	FsOptions  *string  `json:"options",omitempty"`
 }
 
 type Plugin struct {
