@@ -59,18 +59,18 @@ static void	async_task_remove(zbx_async_task_t *task)
 	zbx_free(task);
 }
 
-static const char	*task_state_to_str(zbx_async_task_state_t task_state)
+const char	*zbx_task_state_to_str(zbx_async_task_state_t task_state)
 {
 	switch (task_state)
 	{
 		case ZBX_ASYNC_TASK_WRITE:
-			return "ZBX_ASYNC_TASK_WRITE";
+			return "write";
 		case ZBX_ASYNC_TASK_READ:
-			return "ZBX_ASYNC_TASK_READ";
+			return "read";
 		case ZBX_ASYNC_TASK_STOP:
-			return "ZBX_ASYNC_TASK_STOP";
+			return "stop";
 		case ZBX_ASYNC_TASK_RESOLVE_REVERSE:
-			return "ZBX_ASYNC_TASK_RESOLVE_REVERSE";
+			return "resolve reverse";
 		default:
 			return "unknown";
 	}
@@ -84,7 +84,7 @@ static void	async_event(evutil_socket_t fd, short what, void *arg)
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
-	ret = task->process_cb(what, task->data, &fd, task->address, task->error);
+	ret = task->process_cb(what, task->data, &fd, task->address, task->error, task->timeout_event);
 
 	switch (ret)
 	{
@@ -149,7 +149,7 @@ static void	async_event(evutil_socket_t fd, short what, void *arg)
 
 	}
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __func__, task_state_to_str(ret));
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s", __func__, zbx_task_state_to_str(ret));
 }
 
 static void	async_reverse_dns_event(int err, char type, int count, int ttl, void *addresses, void *arg)
@@ -210,6 +210,35 @@ static void	async_dns_event(int err, struct evutil_addrinfo *ai, void *arg)
 	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
 }
 
+void	zbx_async_dns_update_host_addresses(struct evdns_base *dnsbase)
+{
+	static time_t	time_r = 0, time_h = 0;
+	static double	mtime = 0;
+	zbx_stat_t	buf_r, buf_h;
+
+	if (60 < zbx_time() - mtime)
+	{
+		int	ret_h = zbx_stat("/etc/hosts", &buf_h), ret_r = zbx_stat("/etc/resolv.conf", &buf_r);
+
+		if ((0 == ret_r && time_r != buf_r.st_mtime && 0 != time_r) ||
+			(0 == ret_h && time_h != buf_h.st_mtime && 0 != time_h))
+		{
+			int	ret;
+
+			zabbix_log(LOG_LEVEL_DEBUG, "%s() update host addresses", __func__);
+			evdns_base_clear_host_addresses(dnsbase);
+			if (0 != (ret = evdns_base_resolv_conf_parse(dnsbase, DNS_OPTIONS_ALL, ZBX_RES_CONF_FILE)))
+			{
+				zabbix_log(LOG_LEVEL_ERR, "cannot parse resolv.conf result: %s",
+					zbx_resolv_conf_errstr(ret));
+			}
+		}
+		time_r = buf_r.st_mtime;
+		time_h = buf_h.st_mtime;
+		mtime = zbx_time();
+	}
+}
+
 void	zbx_async_poller_add_task(struct event_base *ev, struct evdns_base *dnsbase, const char *addr,
 		void *data, int timeout, zbx_async_task_process_cb_t process_cb, zbx_async_task_clear_cb_t clear_cb)
 {
@@ -257,6 +286,7 @@ zbx_async_task_state_t	zbx_async_poller_get_task_state_for_event(short event)
 
 	return ZBX_ASYNC_TASK_STOP;
 }
+
 const char	*zbx_resolv_conf_errstr(const int error)
 {
 	switch (error)
@@ -278,4 +308,22 @@ const char	*zbx_resolv_conf_errstr(const int error)
 	}
 }
 
+const char	*zbx_get_event_string(short event)
+{
+
+	if (EV_TIMEOUT & event)
+		return "timeout";
+
+	if (EV_READ & event)
+		return "read";
+
+	if (EV_WRITE & event)
+		return "write";
+
+	if (0 == event)
+		return "init";
+
+	return "unknown";
+}
+
 #endif
