@@ -1,54 +1,56 @@
 /*
-** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
-#include "telnet.h"
+#include "zbxcomms.h"
+#include "comms.h"
 
-#include "common.h"
-#include "log.h"
+#include "zbxlog.h"
+#include "zbxstr.h"
+
+#define CMD_IAC		255
+#define CMD_WILL	251
+#define CMD_WONT	252
+#define CMD_DO		253
+#define CMD_DONT	254
+#define OPT_SGA		3
 
 static char	prompt_char = '\0';
 
-static int	telnet_waitsocket(ZBX_SOCKET socket_fd, int mode)
+static int	telnet_waitsocket(ZBX_SOCKET socket_fd, short mode)
 {
-	struct timeval	tv;
 	int		rc;
-	fd_set		fd, *readfd = NULL, *writefd = NULL;
+	zbx_pollfd_t	pd;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
-	tv.tv_sec = 0;
-	tv.tv_usec = 100000;	/* 1/10 sec */
+	pd.fd = socket_fd;
+	pd.events = mode;
 
-	FD_ZERO(&fd);
-	FD_SET(socket_fd, &fd);
-
-	if (WAIT_READ == mode)
-		readfd = &fd;
-	else
-		writefd = &fd;
-
-	rc = select(ZBX_SOCKET_TO_INT(socket_fd) + 1, readfd, writefd, NULL, &tv);
-
-	if (ZBX_PROTO_ERROR == rc)
+	if (0 > (rc = zbx_socket_poll(&pd, 1, 100)))
 	{
-		zabbix_log(LOG_LEVEL_DEBUG, "%s() rc:%d errno:%d error:[%s]", __func__, rc, zbx_socket_last_error(),
-				strerror_from_system(zbx_socket_last_error()));
+		zabbix_log(LOG_LEVEL_DEBUG, "%s() poll() error rc:%d errno:%d error:[%s]", __func__, rc,
+				zbx_socket_last_error(), zbx_strerror_from_system(zbx_socket_last_error()));
+	}
+	else if (0 < rc && POLLIN != (pd.revents & (POLLIN | POLLERR | POLLHUP | POLLNVAL)))
+	{
+		char	*errmsg;
+
+		errmsg = socket_poll_error(pd.revents);
+
+		zabbix_log(LOG_LEVEL_DEBUG, "%s() %s", __func__, errmsg);
+		zbx_free(errmsg);
+		rc = ZBX_PROTO_ERROR;
 	}
 
 	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%d", __func__, rc);
@@ -56,27 +58,33 @@ static int	telnet_waitsocket(ZBX_SOCKET socket_fd, int mode)
 	return rc;
 }
 
-static ssize_t	telnet_socket_read(ZBX_SOCKET socket_fd, void *buf, size_t count)
+static ssize_t	telnet_socket_read(zbx_socket_t *s, void *buf, size_t count)
 {
 	ssize_t	rc;
 	int	error;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
-	while (ZBX_PROTO_ERROR == (rc = ZBX_TCP_READ(socket_fd, buf, count)))
+	while (ZBX_PROTO_ERROR == (rc = ZBX_TCP_READ(s->socket, buf, count)))
 	{
 		error = zbx_socket_last_error();	/* zabbix_log() resets the error code */
 		zabbix_log(LOG_LEVEL_DEBUG, "%s() rc:%ld errno:%d error:[%s]",
-				__func__, (long int)rc, error, strerror_from_system(error));
+				__func__, (long int)rc, error, zbx_strerror_from_system(error));
 #ifdef _WINDOWS
 		if (WSAEWOULDBLOCK == error)
 #else
 		if (EAGAIN == error)
 #endif
 		{
+			if (SUCCEED != zbx_socket_check_deadline(s))
+			{
+				zabbix_log(LOG_LEVEL_DEBUG, "%s() timeout error", __func__);
+				goto ret;
+			}
+
 			/* wait and if there is still an error or no input available */
 			/* we assume the other side has nothing more to say */
-			if (1 > (rc = telnet_waitsocket(socket_fd, WAIT_READ)))
+			if (1 > (rc = telnet_waitsocket(s->socket, POLLIN)))
 				goto ret;
 
 			continue;
@@ -95,25 +103,31 @@ ret:
 	return rc;
 }
 
-static ssize_t	telnet_socket_write(ZBX_SOCKET socket_fd, const void *buf, size_t count)
+static ssize_t	telnet_socket_write(zbx_socket_t *s, const void *buf, size_t count)
 {
 	ssize_t	rc;
 	int	error;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
-	while (ZBX_PROTO_ERROR == (rc = ZBX_TCP_WRITE(socket_fd, buf, count)))
+	while (ZBX_PROTO_ERROR == (rc = ZBX_TCP_WRITE(s->socket, buf, count)))
 	{
 		error = zbx_socket_last_error();	/* zabbix_log() resets the error code */
 		zabbix_log(LOG_LEVEL_DEBUG, "%s() rc:%ld errno:%d error:[%s]",
-				__func__, (long int)rc, error, strerror_from_system(error));
+				__func__, (long int)rc, error, zbx_strerror_from_system(error));
 #ifdef _WINDOWS
 		if (WSAEWOULDBLOCK == error)
 #else
 		if (EAGAIN == error)
 #endif
 		{
-			telnet_waitsocket(socket_fd, WAIT_WRITE);
+			if (SUCCEED != zbx_socket_check_deadline(s))
+			{
+				zabbix_log(LOG_LEVEL_DEBUG, "%s() timeout error", __func__);
+				break;
+			}
+
+			(void)telnet_waitsocket(s->socket, POLLOUT);
 			continue;
 		}
 
@@ -125,7 +139,10 @@ static ssize_t	telnet_socket_write(ZBX_SOCKET socket_fd, const void *buf, size_t
 	return rc;
 }
 
-static ssize_t	telnet_read(ZBX_SOCKET socket_fd, char *buf, size_t *buf_left, size_t *buf_offset)
+#undef WAIT_READ
+#undef WAIT_WRITE
+
+static ssize_t	telnet_read(zbx_socket_t *s, char *buf, size_t *buf_left, size_t *buf_offset)
 {
 	unsigned char	c, c1, c2, c3;
 	ssize_t		rc = ZBX_PROTO_ERROR;
@@ -134,7 +151,7 @@ static ssize_t	telnet_read(ZBX_SOCKET socket_fd, char *buf, size_t *buf_left, si
 
 	for (;;)
 	{
-		if (1 > (rc = telnet_socket_read(socket_fd, &c1, 1)))
+		if (1 > (rc = telnet_socket_read(s, &c1, 1)))
 			break;
 
 		zabbix_log(LOG_LEVEL_DEBUG, "%s() c1:[%x=%c]", __func__, c1, isprint(c1) ? c1 : ' ');
@@ -142,7 +159,7 @@ static ssize_t	telnet_read(ZBX_SOCKET socket_fd, char *buf, size_t *buf_left, si
 		switch (c1)
 		{
 			case CMD_IAC:
-				while (0 == (rc = telnet_socket_read(socket_fd, &c2, 1)))
+				while (0 == (rc = telnet_socket_read(s, &c2, 1)))
 					;
 
 				if (ZBX_PROTO_ERROR == rc)
@@ -163,7 +180,7 @@ static ssize_t	telnet_read(ZBX_SOCKET socket_fd, char *buf, size_t *buf_left, si
 					case CMD_WONT:
 					case CMD_DO:
 					case CMD_DONT:
-						while (0 == (rc = telnet_socket_read(socket_fd, &c3, 1)))
+						while (0 == (rc = telnet_socket_read(s, &c3, 1)))
 							;
 
 						if (ZBX_PROTO_ERROR == rc)
@@ -175,7 +192,7 @@ static ssize_t	telnet_read(ZBX_SOCKET socket_fd, char *buf, size_t *buf_left, si
 						/* unless it is Suppress Go Ahead (SGA)        */
 
 						c = CMD_IAC;
-						telnet_socket_write(socket_fd, &c, 1);
+						telnet_socket_write(s, &c, 1);
 
 						if (CMD_WONT == c2)
 							c = CMD_DONT;	/* the only valid response */
@@ -186,8 +203,8 @@ static ssize_t	telnet_read(ZBX_SOCKET socket_fd, char *buf, size_t *buf_left, si
 						else
 							c = (c2 == CMD_DO ? CMD_WONT : CMD_DONT);
 
-						telnet_socket_write(socket_fd, &c, 1);
-						telnet_socket_write(socket_fd, &c3, 1);
+						telnet_socket_write(s, &c, 1);
+						telnet_socket_write(s, &c3, 1);
 						break;
 					default:
 						break;
@@ -208,6 +225,13 @@ end:
 	return rc;
 }
 
+#undef CMD_IAC
+#undef CMD_WILL
+#undef CMD_WONT
+#undef CMD_DO
+#undef CMD_DONT
+#undef OPT_SGA
+
 /******************************************************************************
  *                                                                            *
  * Comments: converts CR+LF to Unix LF and clears CR+NUL                      *
@@ -305,7 +329,7 @@ static void	telnet_rm_prompt(const char *buf, size_t *offset)
 	}
 }
 
-int	telnet_test_login(ZBX_SOCKET socket_fd)
+int	zbx_telnet_test_login(zbx_socket_t *s)
 {
 	char	buf[MAX_BUFFER_LEN];
 	size_t	sz, offset;
@@ -315,7 +339,7 @@ int	telnet_test_login(ZBX_SOCKET socket_fd)
 
 	sz = sizeof(buf);
 	offset = 0;
-	while (ZBX_PROTO_ERROR != (rc = telnet_read(socket_fd, buf, &sz, &offset)))
+	while (ZBX_PROTO_ERROR != (rc = telnet_read(s, buf, &sz, &offset)))
 	{
 		if (':' == telnet_lastchar(buf, offset))
 			break;
@@ -332,7 +356,7 @@ int	telnet_test_login(ZBX_SOCKET socket_fd)
 	return ret;
 }
 
-int	telnet_login(ZBX_SOCKET socket_fd, const char *username, const char *password, AGENT_RESULT *result)
+int	zbx_telnet_login(zbx_socket_t *s, const char *username, const char *password, AGENT_RESULT *result)
 {
 	char	buf[MAX_BUFFER_LEN], c;
 	size_t	sz, offset;
@@ -342,7 +366,7 @@ int	telnet_login(ZBX_SOCKET socket_fd, const char *username, const char *passwor
 
 	sz = sizeof(buf);
 	offset = 0;
-	while (ZBX_PROTO_ERROR != (rc = telnet_read(socket_fd, buf, &sz, &offset)))
+	while (ZBX_PROTO_ERROR != (rc = telnet_read(s, buf, &sz, &offset)))
 	{
 		if (':' == telnet_lastchar(buf, offset))
 			break;
@@ -357,12 +381,12 @@ int	telnet_login(ZBX_SOCKET socket_fd, const char *username, const char *passwor
 		goto fail;
 	}
 
-	telnet_socket_write(socket_fd, username, strlen(username));
-	telnet_socket_write(socket_fd, "\r\n", 2);
+	telnet_socket_write(s, username, strlen(username));
+	telnet_socket_write(s, "\r\n", 2);
 
 	sz = sizeof(buf);
 	offset = 0;
-	while (ZBX_PROTO_ERROR != (rc = telnet_read(socket_fd, buf, &sz, &offset)))
+	while (ZBX_PROTO_ERROR != (rc = telnet_read(s, buf, &sz, &offset)))
 	{
 		if (':' == telnet_lastchar(buf, offset))
 			break;
@@ -377,12 +401,12 @@ int	telnet_login(ZBX_SOCKET socket_fd, const char *username, const char *passwor
 		goto fail;
 	}
 
-	telnet_socket_write(socket_fd, password, strlen(password));
-	telnet_socket_write(socket_fd, "\r\n", 2);
+	telnet_socket_write(s, password, strlen(password));
+	telnet_socket_write(s, "\r\n", 2);
 
 	sz = sizeof(buf);
 	offset = 0;
-	while (ZBX_PROTO_ERROR != (rc = telnet_read(socket_fd, buf, &sz, &offset)))
+	while (ZBX_PROTO_ERROR != (rc = telnet_read(s, buf, &sz, &offset)))
 	{
 		if ('$' == (c = telnet_lastchar(buf, offset)) || '#' == c || '>' == c || '%' == c)
 		{
@@ -407,13 +431,13 @@ fail:
 	return ret;
 }
 
-int	telnet_execute(ZBX_SOCKET socket_fd, const char *command, AGENT_RESULT *result, const char *encoding)
+int	zbx_telnet_execute(zbx_socket_t *s, const char *command, AGENT_RESULT *result, const char *encoding)
 {
-	char	buf[MAX_BUFFER_LEN];
-	size_t	sz, offset;
-	int	rc, ret = FAIL;
-	char	*command_lf = NULL, *command_crlf = NULL;
-	size_t	i, offset_lf, offset_crlf;
+	char		buf[MAX_BUFFER_LEN];
+	char		*utf8_result, *err_msg = NULL, *command_lf = NULL, *command_crlf = NULL;
+	size_t		sz, offset;
+	int		rc, ret = FAIL;
+	size_t		i, offset_lf, offset_crlf;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
 
@@ -428,12 +452,13 @@ int	telnet_execute(ZBX_SOCKET socket_fd, const char *command, AGENT_RESULT *resu
 	command_crlf = (char *)zbx_malloc(command_crlf, offset_lf * 2 + 1);
 	convert_unix_to_telnet_eol(command_lf, offset_lf, command_crlf, &offset_crlf);
 
-	telnet_socket_write(socket_fd, command_crlf, offset_crlf);
-	telnet_socket_write(socket_fd, "\r\n", 2);
+	telnet_socket_write(s, command_crlf, offset_crlf);
+	telnet_socket_write(s, "\r\n", 2);
 
 	sz = sizeof(buf);
 	offset = 0;
-	while (ZBX_PROTO_ERROR != (rc = telnet_read(socket_fd, buf, &sz, &offset)))
+
+	while (ZBX_PROTO_ERROR != (rc = telnet_read(s, buf, &sz, &offset)))
 	{
 		if (prompt_char == telnet_lastchar(buf, offset))
 			break;
@@ -444,8 +469,16 @@ int	telnet_execute(ZBX_SOCKET socket_fd, const char *command, AGENT_RESULT *resu
 
 	if (ZBX_PROTO_ERROR == rc)
 	{
+		const char	*err_msg_loc;
+
+		if (SUCCEED == zbx_socket_check_deadline(s))
+			err_msg_loc = zbx_strerror_from_system(zbx_socket_last_error());
+		else
+			err_msg_loc = "timeout occurred";
+
 		SET_MSG_RESULT(result, zbx_dsprintf(NULL, "Cannot find prompt after command execution: %s",
-				strerror_from_system(zbx_socket_last_error())));
+				err_msg_loc));
+
 		goto fail;
 	}
 
@@ -479,8 +512,17 @@ int	telnet_execute(ZBX_SOCKET socket_fd, const char *command, AGENT_RESULT *resu
 		offset--;
 	buf[offset] = '\0';
 
-	SET_STR_RESULT(result, convert_to_utf8(buf, offset, encoding));
-	ret = SUCCEED;
+	if (NULL == (utf8_result = zbx_convert_to_utf8(buf, offset, encoding, &err_msg)))
+	{
+		SET_MSG_RESULT(result, zbx_dsprintf(NULL, "Cannot convert result to utf8: %s.", err_msg));
+		zbx_free(err_msg);
+		goto fail;
+	}
+	else
+	{
+		SET_TEXT_RESULT(result, utf8_result);
+		ret = SUCCEED;
+	}
 fail:
 	zbx_free(command_lf);
 	zbx_free(command_crlf);
