@@ -1,26 +1,22 @@
 /*
-** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
-#include "common.h"
-#include "db.h"
 #include "dbupgrade.h"
-#include "log.h"
+
+#include "zbxnum.h"
+#include "zbxexpr.h"
+#include "zbxdbhigh.h"
 
 /*
  * 3.2 development database patches
@@ -50,21 +46,21 @@ static int	DBpatch_3010003(void)
 
 static int	DBpatch_3010004(void)
 {
-	const ZBX_FIELD	field = {"recovery_mode", "0", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
+	const zbx_db_field_t	field = {"recovery_mode", "0", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
 
 	return DBadd_field("triggers", &field);
 }
 
 static int	DBpatch_3010005(void)
 {
-	const ZBX_FIELD	field = {"recovery_expression", "", NULL, NULL, 2048, ZBX_TYPE_CHAR, ZBX_NOTNULL, 0};
+	const zbx_db_field_t	field = {"recovery_expression", "", NULL, NULL, 2048, ZBX_TYPE_CHAR, ZBX_NOTNULL, 0};
 
 	return DBadd_field("triggers", &field);
 }
 
 static int	DBpatch_3010006(void)
 {
-	const ZBX_TABLE table =
+	const zbx_db_table_t	table =
 			{"trigger_tag", "triggertagid", 0,
 				{
 					{"triggertagid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, ZBX_NOTNULL, 0},
@@ -86,14 +82,14 @@ static int	DBpatch_3010007(void)
 
 static int	DBpatch_3010008(void)
 {
-	const ZBX_FIELD	field = {"triggerid", NULL, "triggers", "triggerid", 0, 0, 0, ZBX_FK_CASCADE_DELETE};
+	const zbx_db_field_t	field = {"triggerid", NULL, "triggers", "triggerid", 0, 0, 0, ZBX_FK_CASCADE_DELETE};
 
 	return DBadd_foreign_key("trigger_tag", 1, &field);
 }
 
 static int	DBpatch_3010009(void)
 {
-	const ZBX_TABLE table =
+	const zbx_db_table_t	table =
 			{"event_tag", "eventtagid", 0,
 				{
 					{"eventtagid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, ZBX_NOTNULL, 0},
@@ -115,28 +111,28 @@ static int	DBpatch_3010010(void)
 
 static int	DBpatch_3010011(void)
 {
-	const ZBX_FIELD	field = {"eventid", NULL, "events", "eventid", 0, 0, 0, ZBX_FK_CASCADE_DELETE};
+	const zbx_db_field_t	field = {"eventid", NULL, "events", "eventid", 0, 0, 0, ZBX_FK_CASCADE_DELETE};
 
 	return DBadd_foreign_key("event_tag", 1, &field);
 }
 
 static int	DBpatch_3010012(void)
 {
-	const ZBX_FIELD	field = {"value2", "", NULL, NULL, 255, ZBX_TYPE_CHAR, ZBX_NOTNULL, 0};
+	const zbx_db_field_t	field = {"value2", "", NULL, NULL, 255, ZBX_TYPE_CHAR, ZBX_NOTNULL, 0};
 
 	return DBadd_field("conditions", &field);
 }
 
 static int	DBpatch_3010013(void)
 {
-	const ZBX_FIELD	field = {"maintenance_mode", "1", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
+	const zbx_db_field_t	field = {"maintenance_mode", "1", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
 
 	return DBadd_field("actions", &field);
 }
 
 static int	DBpatch_3010014(void)
 {
-	const ZBX_TABLE table =
+	const zbx_db_table_t	table =
 			{"problem", "eventid", 0,
 				{
 					{"eventid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, ZBX_NOTNULL, 0},
@@ -158,7 +154,7 @@ static int	DBpatch_3010015(void)
 
 static int	DBpatch_3010016(void)
 {
-	const ZBX_FIELD field = {"eventid", NULL, "events", "eventid", 0, ZBX_TYPE_ID, ZBX_NOTNULL,
+	const zbx_db_field_t	field = {"eventid", NULL, "events", "eventid", 0, ZBX_TYPE_ID, ZBX_NOTNULL,
 			ZBX_FK_CASCADE_DELETE};
 
 	return DBadd_foreign_key("problem", 1, &field);
@@ -166,7 +162,7 @@ static int	DBpatch_3010016(void)
 
 static int	DBpatch_3010017(void)
 {
-	const ZBX_TABLE table =
+	const zbx_db_table_t	table =
 			{"event_recovery", "eventid", 0,
 				{
 					{"eventid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, ZBX_NOTNULL, 0},
@@ -186,7 +182,7 @@ static int	DBpatch_3010018(void)
 
 static int	DBpatch_3010019(void)
 {
-	const ZBX_FIELD field = {"eventid", NULL, "events", "eventid", 0, ZBX_TYPE_ID, ZBX_NOTNULL,
+	const zbx_db_field_t	field = {"eventid", NULL, "events", "eventid", 0, ZBX_TYPE_ID, ZBX_NOTNULL,
 			ZBX_FK_CASCADE_DELETE};
 
 	return DBadd_foreign_key("event_recovery", 1, &field);
@@ -194,7 +190,7 @@ static int	DBpatch_3010019(void)
 
 static int	DBpatch_3010020(void)
 {
-	const ZBX_FIELD field = {"r_eventid", NULL, "events", "eventid", 0, ZBX_TYPE_ID, ZBX_NOTNULL,
+	const zbx_db_field_t	field = {"r_eventid", NULL, "events", "eventid", 0, ZBX_TYPE_ID, ZBX_NOTNULL,
 			ZBX_FK_CASCADE_DELETE};
 
 	return DBadd_foreign_key("event_recovery", 2, &field);
@@ -253,8 +249,8 @@ static int	DBpatch_3010021_trigger_events_compare_func(const void *d1, const voi
  ******************************************************************************/
 static int	DBpatch_3010021_update_event_recovery(zbx_hashset_t *events, zbx_uint64_t *eventid)
 {
-	DB_ROW			row;
-	DB_RESULT		result;
+	zbx_db_row_t		row;
+	zbx_db_result_t		result;
 	char			*sql = NULL;
 	size_t			sql_alloc = 4096, sql_offset = 0;
 	int			i, value, ret = FAIL;
@@ -273,12 +269,12 @@ static int	DBpatch_3010021_update_event_recovery(zbx_hashset_t *events, zbx_uint
 			*eventid);
 
 	/* process events by 10k large batches */
-	if (NULL == (result = DBselectN(sql, 10000)))
+	if (NULL == (result = zbx_db_select_n(sql, 10000)))
 		goto out;
 
-	zbx_db_insert_prepare(&db_insert, "event_recovery", "eventid", "r_eventid", NULL);
+	zbx_db_insert_prepare(&db_insert, "event_recovery", "eventid", "r_eventid", (char *)NULL);
 
-	while (NULL != (row = DBfetch(result)))
+	while (NULL != (row = zbx_db_fetch(result)))
 	{
 		object_events_local.source = atoi(row[0]);
 		object_events_local.object = atoi(row[1]);
@@ -318,7 +314,7 @@ static int	DBpatch_3010021_update_event_recovery(zbx_hashset_t *events, zbx_uint
 			zbx_vector_uint64_clear(&object_events->eventids);
 		}
 	}
-	DBfree_result(result);
+	zbx_db_free_result(result);
 
 	ret = zbx_db_insert_execute(&db_insert);
 	zbx_db_insert_clean(&db_insert);
@@ -339,7 +335,7 @@ static int	DBpatch_3010021(void)
 
 	zbx_hashset_create(&events, 1024, DBpatch_3010021_trigger_events_hash_func,
 			DBpatch_3010021_trigger_events_compare_func);
-	zbx_db_insert_prepare(&db_insert, "problem", "eventid", "source", "object", "objectid", NULL);
+	zbx_db_insert_prepare(&db_insert, "problem", "eventid", "source", "object", "objectid", (char *)NULL);
 
 	do
 	{
@@ -367,7 +363,8 @@ static int	DBpatch_3010021(void)
 				goto out;
 
 			zbx_db_insert_clean(&db_insert);
-			zbx_db_insert_prepare(&db_insert, "problem", "eventid", "source", "object", "objectid", NULL);
+			zbx_db_insert_prepare(&db_insert, "problem", "eventid", "source", "object", "objectid",
+					(char *)NULL);
 		}
 
 		zbx_vector_uint64_destroy(&object_events->eventids);
@@ -386,7 +383,7 @@ out:
 
 static int	DBpatch_3010022(void)
 {
-	const ZBX_FIELD	field = {"recovery", "0", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
+	const zbx_db_field_t	field = {"recovery", "0", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
 
 	return DBadd_field("operations", &field);
 }
@@ -394,27 +391,29 @@ static int	DBpatch_3010022(void)
 static int	DBpatch_3010023(void)
 {
 	zbx_db_insert_t	db_insert, db_insert_msg;
-	DB_ROW		row;
-	DB_RESULT	result;
+	zbx_db_row_t	row;
+	zbx_db_result_t	result;
 	int		ret, actions_num;
 	zbx_uint64_t	actionid, operationid;
 
-	result = DBselect("select count(*) from actions where recovery_msg=1");
-	if (NULL == (row = DBfetch(result)) || 0 == (actions_num = atoi(row[0])))
+	result = zbx_db_select("select count(*) from actions where recovery_msg=1");
+	if (NULL == (row = zbx_db_fetch(result)) || 0 == (actions_num = atoi(row[0])))
 	{
 		ret = SUCCEED;
 		goto out;
 	}
 
-	operationid = DBget_maxid_num("operations", actions_num);
+	operationid = zbx_db_get_maxid_num("operations", actions_num);
 
-	zbx_db_insert_prepare(&db_insert, "operations", "operationid", "actionid", "operationtype", "recovery", NULL);
-	zbx_db_insert_prepare(&db_insert_msg, "opmessage", "operationid", "default_msg", "subject", "message", NULL);
+	zbx_db_insert_prepare(&db_insert, "operations", "operationid", "actionid", "operationtype", "recovery",
+			(char *)NULL);
+	zbx_db_insert_prepare(&db_insert_msg, "opmessage", "operationid", "default_msg", "subject", "message",
+			(char *)NULL);
 
-	DBfree_result(result);
-	result = DBselect("select actionid,r_shortdata,r_longdata from actions where recovery_msg=1");
+	zbx_db_free_result(result);
+	result = zbx_db_select("select actionid,r_shortdata,r_longdata from actions where recovery_msg=1");
 
-	while (NULL != (row = DBfetch(result)))
+	while (NULL != (row = zbx_db_fetch(result)))
 	{
 		ZBX_STR2UINT64(actionid, row[0]);
 		/* operationtype: 11 - OPERATION_TYPE_RECOVERY_MESSAGE */
@@ -431,7 +430,7 @@ static int	DBpatch_3010023(void)
 	zbx_db_insert_clean(&db_insert);
 
 out:
-	DBfree_result(result);
+	zbx_db_free_result(result);
 
 	return ret;
 }
@@ -459,24 +458,24 @@ out:
  ******************************************************************************/
 static int	DBpatch_3010024_validate_action(zbx_uint64_t actionid, int eventsource, int evaltype, int recovery_msg)
 {
-	DB_ROW		row;
-	DB_RESULT	result;
+	zbx_db_row_t	row;
+	zbx_db_result_t	result;
 	int		conditiontype, ret = ZBX_3010024_ACTION_DISABLE, value;
 
-	/* evaltype: 0 - CONDITION_EVAL_TYPE_AND_OR, 1 - CONDITION_EVAL_TYPE_AND */
+	/* evaltype: 0 - ZBX_CONDITION_EVAL_TYPE_AND_OR, 1 - ZBX_CONDITION_EVAL_TYPE_AND */
 	if (evaltype != 0 && evaltype != 1)
 		return ret;
 
-	result = DBselect("select conditiontype,value from conditions where actionid=" ZBX_FS_UI64, actionid);
+	result = zbx_db_select("select conditiontype,value from conditions where actionid=" ZBX_FS_UI64, actionid);
 
-	while (NULL != (row = DBfetch(result)))
+	while (NULL != (row = zbx_db_fetch(result)))
 	{
 		conditiontype = atoi(row[0]);
 
 		/* eventsource: 0 - EVENT_SOURCE_TRIGGERS, 3 - EVENT_SOURCE_INTERNAL  */
 		if (0 == eventsource)
 		{
-			/* conditiontype: 5 - CONDITION_TYPE_TRIGGER_VALUE */
+			/* conditiontype: 5 - ZBX_CONDITION_TYPE_TRIGGER_VALUE */
 			if (5 != conditiontype)
 				continue;
 
@@ -508,7 +507,7 @@ static int	DBpatch_3010024_validate_action(zbx_uint64_t actionid, int eventsourc
 		}
 		else if (3 == eventsource)
 		{
-			/* conditiontype: 23 -  CONDITION_TYPE_EVENT_TYPE */
+			/* conditiontype: 23 -  ZBX_CONDITION_TYPE_EVENT_TYPE */
 			if (23 != conditiontype)
 				continue;
 
@@ -532,11 +531,11 @@ static int	DBpatch_3010024_validate_action(zbx_uint64_t actionid, int eventsourc
 				ret = ZBX_3010024_ACTION_NOTHING;
 		}
 	}
-	DBfree_result(result);
+	zbx_db_free_result(result);
 
 	if (ZBX_3010024_ACTION_CONVERT == ret)
 	{
-		result = DBselect("select o.operationtype,o.esc_step_from,o.esc_step_to,count(oc.opconditionid)"
+		result = zbx_db_select("select o.operationtype,o.esc_step_from,o.esc_step_to,count(oc.opconditionid)"
 					" from operations o"
 					" left join opconditions oc"
 						" on oc.operationid=o.operationid"
@@ -544,7 +543,7 @@ static int	DBpatch_3010024_validate_action(zbx_uint64_t actionid, int eventsourc
 					" group by o.operationid,o.operationtype,o.esc_step_from,o.esc_step_to",
 					actionid);
 
-		while (NULL != (row = DBfetch(result)))
+		while (NULL != (row = zbx_db_fetch(result)))
 		{
 			/* cannot convert action if:                                                    */
 			/*   there are escalation steps that aren't executed at the escalation start    */
@@ -557,7 +556,7 @@ static int	DBpatch_3010024_validate_action(zbx_uint64_t actionid, int eventsourc
 			}
 		}
 
-		DBfree_result(result);
+		zbx_db_free_result(result);
 	}
 
 	return ret;
@@ -565,8 +564,8 @@ static int	DBpatch_3010024_validate_action(zbx_uint64_t actionid, int eventsourc
 
 static int	DBpatch_3010024(void)
 {
-	DB_ROW			row;
-	DB_RESULT		result;
+	zbx_db_row_t		row;
+	zbx_db_result_t		result;
 	zbx_vector_uint64_t	actionids_disable, actionids_convert;
 	int			ret, evaltype, eventsource, recovery_msg;
 	zbx_uint64_t		actionid;
@@ -575,10 +574,10 @@ static int	DBpatch_3010024(void)
 	zbx_vector_uint64_create(&actionids_convert);
 
 	/* eventsource: 0 - EVENT_SOURCE_TRIGGERS, 3 - EVENT_SOURCE_INTERNAL */
-	result = DBselect("select actionid,name,eventsource,evaltype,recovery_msg from actions"
+	result = zbx_db_select("select actionid,name,eventsource,evaltype,recovery_msg from actions"
 			" where eventsource in (0,3)");
 
-	while (NULL != (row = DBfetch(result)))
+	while (NULL != (row = zbx_db_fetch(result)))
 	{
 		ZBX_STR2UINT64(actionid, row[0]);
 		eventsource = atoi(row[2]);
@@ -601,7 +600,7 @@ static int	DBpatch_3010024(void)
 					" operations during database upgrade.", row[1]);
 		}
 	}
-	DBfree_result(result);
+	zbx_db_free_result(result);
 
 	ret = SUCCEED;
 
@@ -610,14 +609,14 @@ static int	DBpatch_3010024(void)
 		char	*sql = NULL;
 		size_t	sql_alloc = 0, sql_offset = 0;
 
-		DBbegin_multiple_update(&sql, &sql_alloc, &sql_offset);
+		zbx_db_begin_multiple_update(&sql, &sql_alloc, &sql_offset);
 
 		if (0 != actionids_disable.values_num)
 		{
-			/* status: 1 - ACTION_STATUS_DISABLED */
+			/* status: 1 - ZBX_ACTION_STATUS_DISABLED */
 
 			zbx_strcpy_alloc(&sql, &sql_alloc, &sql_offset, "update actions set status=1 where");
-			DBadd_condition_alloc(&sql, &sql_alloc, &sql_offset, "actionid", actionids_disable.values,
+			zbx_db_add_condition_alloc(&sql, &sql_alloc, &sql_offset, "actionid", actionids_disable.values,
 					actionids_disable.values_num);
 			zbx_strcpy_alloc(&sql, &sql_alloc, &sql_offset, ";\n");
 		}
@@ -628,19 +627,19 @@ static int	DBpatch_3010024(void)
 					" set r_shortdata=def_shortdata,"
 						"r_longdata=def_longdata"
 					" where");
-			DBadd_condition_alloc(&sql, &sql_alloc, &sql_offset, "actionid", actionids_convert.values,
+			zbx_db_add_condition_alloc(&sql, &sql_alloc, &sql_offset, "actionid", actionids_convert.values,
 					actionids_convert.values_num);
 			zbx_strcpy_alloc(&sql, &sql_alloc, &sql_offset, ";\n");
 
 			zbx_strcpy_alloc(&sql, &sql_alloc, &sql_offset, "update operations set recovery=1 where");
-			DBadd_condition_alloc(&sql, &sql_alloc, &sql_offset, "actionid", actionids_convert.values,
+			zbx_db_add_condition_alloc(&sql, &sql_alloc, &sql_offset, "actionid", actionids_convert.values,
 					actionids_convert.values_num);
 			zbx_strcpy_alloc(&sql, &sql_alloc, &sql_offset, ";\n");
 		}
 
-		DBend_multiple_update(&sql, &sql_alloc, &sql_offset);
+		zbx_db_end_multiple_update(&sql, &sql_alloc, &sql_offset);
 
-		if (ZBX_DB_OK > DBexecute("%s", sql))
+		if (ZBX_DB_OK > zbx_db_execute("%s", sql))
 			ret = FAIL;
 
 		zbx_free(sql);
@@ -683,8 +682,8 @@ static int	DBpatch_3010025(void)
 static void	DBpatch_3010026_get_conditionids(zbx_uint64_t actionid, const char *name, int eventsource,
 		zbx_vector_uint64_t *conditionids)
 {
-	DB_ROW		row;
-	DB_RESULT	result;
+	zbx_db_row_t	row;
+	zbx_db_result_t	result;
 	zbx_uint64_t	conditionid;
 	char		*condition = NULL;
 	size_t		condition_alloc = 0, condition_offset = 0;
@@ -693,16 +692,16 @@ static void	DBpatch_3010026_get_conditionids(zbx_uint64_t actionid, const char *
 	/* eventsource: 0 - EVENT_SOURCE_TRIGGERS, 3 - EVENT_SOURCE_INTERNAL  */
 	if (0 == eventsource)
 	{
-		/* conditiontype: 5 - CONDITION_TYPE_TRIGGER_VALUE */
-		result = DBselect("select conditionid,value from conditions"
+		/* conditiontype: 5 - ZBX_CONDITION_TYPE_TRIGGER_VALUE */
+		result = zbx_db_select("select conditionid,value from conditions"
 				" where actionid=" ZBX_FS_UI64
 					" and conditiontype=5",
 				actionid);
 	}
 	else if (3 == eventsource)
 	{
-		/* conditiontype: 23 -  CONDITION_TYPE_EVENT_TYPE */
-		result = DBselect("select conditionid,value from conditions"
+		/* conditiontype: 23 -  ZBX_CONDITION_TYPE_EVENT_TYPE */
+		result = zbx_db_select("select conditionid,value from conditions"
 				" where actionid=" ZBX_FS_UI64
 					" and conditiontype=23"
 					" and value in ('1', '3', '5')",
@@ -711,7 +710,7 @@ static void	DBpatch_3010026_get_conditionids(zbx_uint64_t actionid, const char *
 	else
 		return;
 
-	while (NULL != (row = DBfetch(result)))
+	while (NULL != (row = zbx_db_fetch(result)))
 	{
 		ZBX_STR2UINT64(conditionid, row[0]);
 		zbx_vector_uint64_append(conditionids, conditionid);
@@ -746,7 +745,7 @@ static void	DBpatch_3010026_get_conditionids(zbx_uint64_t actionid, const char *
 	}
 
 	zbx_free(condition);
-	DBfree_result(result);
+	zbx_db_free_result(result);
 }
 
 /******************************************************************************
@@ -1018,8 +1017,8 @@ static int	DBpatch_3010026_expression_remove_values(char *expression, const zbx_
 
 static int	DBpatch_3010026(void)
 {
-	DB_ROW			row;
-	DB_RESULT		result;
+	zbx_db_row_t		row;
+	zbx_db_result_t		result;
 	zbx_vector_uint64_t	conditionids, actionids;
 	int			ret = FAIL, evaltype, index, i, eventsource;
 	zbx_uint64_t		actionid;
@@ -1030,11 +1029,11 @@ static int	DBpatch_3010026(void)
 	zbx_vector_uint64_create(&conditionids);
 	zbx_vector_uint64_create(&actionids);
 	zbx_vector_str_create(&filter);
-	DBbegin_multiple_update(&sql, &sql_alloc, &sql_offset);
+	zbx_db_begin_multiple_update(&sql, &sql_alloc, &sql_offset);
 
-	result = DBselect("select actionid,eventsource,evaltype,formula,name from actions");
+	result = zbx_db_select("select actionid,eventsource,evaltype,formula,name from actions");
 
-	while (NULL != (row = DBfetch(result)))
+	while (NULL != (row = zbx_db_fetch(result)))
 	{
 		ZBX_STR2UINT64(actionid, row[0]);
 		eventsource = atoi(row[1]);
@@ -1043,7 +1042,7 @@ static int	DBpatch_3010026(void)
 		index = conditionids.values_num;
 		DBpatch_3010026_get_conditionids(actionid, row[4], eventsource, &conditionids);
 
-		/* evaltype: 3 - CONDITION_EVAL_TYPE_EXPRESSION */
+		/* evaltype: 3 - ZBX_CONDITION_EVAL_TYPE_EXPRESSION */
 		if (3 != evaltype)
 			continue;
 
@@ -1065,15 +1064,15 @@ static int	DBpatch_3010026(void)
 		zbx_free(formula);
 		zbx_vector_str_clear_ext(&filter, zbx_str_free);
 
-		if (SUCCEED != DBexecute_overflowed_sql(&sql, &sql_alloc, &sql_offset))
+		if (SUCCEED != zbx_db_execute_overflowed_sql(&sql, &sql_alloc, &sql_offset))
 			goto out;
 	}
 
-	DBend_multiple_update(&sql, &sql_alloc, &sql_offset);
+	zbx_db_end_multiple_update(&sql, &sql_alloc, &sql_offset);
 
 	if (16 < sql_offset)	/* in ORACLE always present begin..end; */
 	{
-		if (ZBX_DB_OK > DBexecute("%s", sql))
+		if (ZBX_DB_OK > zbx_db_execute("%s", sql))
 			goto out;
 	}
 
@@ -1081,23 +1080,23 @@ static int	DBpatch_3010026(void)
 	{
 		sql_offset = 0;
 		zbx_strcpy_alloc(&sql, &sql_alloc, &sql_offset, "delete from conditions where");
-		DBadd_condition_alloc(&sql, &sql_alloc, &sql_offset, "conditionid", conditionids.values,
+		zbx_db_add_condition_alloc(&sql, &sql_alloc, &sql_offset, "conditionid", conditionids.values,
 				conditionids.values_num);
 
-		if (ZBX_DB_OK > DBexecute("%s", sql))
+		if (ZBX_DB_OK > zbx_db_execute("%s", sql))
 			goto out;
 	}
 
 	/* reset action evaltype to AND/OR if it has no more conditions left */
 
-	DBfree_result(result);
-	result = DBselect("select a.actionid,a.name,a.evaltype,count(c.conditionid)"
+	zbx_db_free_result(result);
+	result = zbx_db_select("select a.actionid,a.name,a.evaltype,count(c.conditionid)"
 			" from actions a"
 			" left join conditions c"
 				" on a.actionid=c.actionid"
 			" group by a.actionid,a.name,a.evaltype");
 
-	while (NULL != (row = DBfetch(result)))
+	while (NULL != (row = zbx_db_fetch(result)))
 	{
 		/* reset evaltype to AND/OR (0) if action has no more conditions and it's evaltype is not AND/OR */
 		if (0 == atoi(row[3]) && 0 != atoi(row[2]))
@@ -1115,17 +1114,17 @@ static int	DBpatch_3010026(void)
 		sql_offset = 0;
 		zbx_strcpy_alloc(&sql, &sql_alloc, &sql_offset, "update actions set evaltype=0 where");
 
-		DBadd_condition_alloc(&sql, &sql_alloc, &sql_offset, "actionid", actionids.values,
+		zbx_db_add_condition_alloc(&sql, &sql_alloc, &sql_offset, "actionid", actionids.values,
 				actionids.values_num);
 
-		if (ZBX_DB_OK > DBexecute("%s", sql))
+		if (ZBX_DB_OK > zbx_db_execute("%s", sql))
 			goto out;
 	}
 
 	ret = SUCCEED;
 
 out:
-	DBfree_result(result);
+	zbx_db_free_result(result);
 	zbx_free(sql);
 	zbx_vector_str_destroy(&filter);
 	zbx_vector_uint64_destroy(&actionids);
@@ -1136,49 +1135,49 @@ out:
 
 static int	DBpatch_3010027(void)
 {
-	const ZBX_FIELD	field = {"correlation_mode", "0", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
+	const zbx_db_field_t	field = {"correlation_mode", "0", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
 
 	return DBadd_field("triggers", &field);
 }
 
 static int	DBpatch_3010028(void)
 {
-	const ZBX_FIELD	field = {"correlation_tag", "", NULL, NULL, 255, ZBX_TYPE_CHAR, ZBX_NOTNULL, 0};
+	const zbx_db_field_t	field = {"correlation_tag", "", NULL, NULL, 255, ZBX_TYPE_CHAR, ZBX_NOTNULL, 0};
 
 	return DBadd_field("triggers", &field);
 }
 
 static int	DBpatch_3010029(void)
 {
-	const ZBX_FIELD	field = {"clock", "0", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
+	const zbx_db_field_t	field = {"clock", "0", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
 
 	return DBadd_field("problem", &field);
 }
 
 static int	DBpatch_3010030(void)
 {
-	const ZBX_FIELD	field = {"ns", "0", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
+	const zbx_db_field_t	field = {"ns", "0", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
 
 	return DBadd_field("problem", &field);
 }
 
 static int	DBpatch_3010031(void)
 {
-	const ZBX_FIELD	field = {"r_eventid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, 0, 0};
+	const zbx_db_field_t	field = {"r_eventid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, 0, 0};
 
 	return DBadd_field("problem", &field);
 }
 
 static int	DBpatch_3010032(void)
 {
-	const ZBX_FIELD	field = {"r_clock", "0", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
+	const zbx_db_field_t	field = {"r_clock", "0", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
 
 	return DBadd_field("problem", &field);
 }
 
 static int	DBpatch_3010033(void)
 {
-	const ZBX_FIELD	field = {"r_ns", "0", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
+	const zbx_db_field_t	field = {"r_ns", "0", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
 
 	return DBadd_field("problem", &field);
 }
@@ -1190,14 +1189,14 @@ static int	DBpatch_3010034(void)
 
 static int	DBpatch_3010035(void)
 {
-	const ZBX_FIELD	field = {"r_eventid", NULL, "events", "eventid", 0, 0, 0, ZBX_FK_CASCADE_DELETE};
+	const zbx_db_field_t	field = {"r_eventid", NULL, "events", "eventid", 0, 0, 0, ZBX_FK_CASCADE_DELETE};
 
 	return DBadd_foreign_key("problem", 2, &field);
 }
 
 static int	DBpatch_3010036(void)
 {
-	const ZBX_TABLE table =
+	const zbx_db_table_t	table =
 			{"problem_tag", "problemtagid", 0,
 				{
 					{"problemtagid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, ZBX_NOTNULL, 0},
@@ -1224,14 +1223,14 @@ static int	DBpatch_3010038(void)
 
 static int	DBpatch_3010039(void)
 {
-	const ZBX_FIELD	field = {"eventid", NULL, "problem", "eventid", 0, 0, 0, ZBX_FK_CASCADE_DELETE};
+	const zbx_db_field_t	field = {"eventid", NULL, "problem", "eventid", 0, 0, 0, ZBX_FK_CASCADE_DELETE};
 
 	return DBadd_foreign_key("problem_tag", 1, &field);
 }
 
 static int	DBpatch_3010042(void)
 {
-	if (ZBX_DB_OK <= DBexecute("update config set ok_period=%d where ok_period>%d", SEC_PER_DAY, SEC_PER_DAY))
+	if (ZBX_DB_OK <= zbx_db_execute("update config set ok_period=%d where ok_period>%d", SEC_PER_DAY, SEC_PER_DAY))
 		return SUCCEED;
 
 	return FAIL;
@@ -1239,7 +1238,7 @@ static int	DBpatch_3010042(void)
 
 static int	DBpatch_3010043(void)
 {
-	if (ZBX_DB_OK <= DBexecute("update config set blink_period=%d where blink_period>%d", SEC_PER_DAY, SEC_PER_DAY))
+	if (ZBX_DB_OK <= zbx_db_execute("update config set blink_period=%d where blink_period>%d", SEC_PER_DAY, SEC_PER_DAY))
 		return SUCCEED;
 
 	return FAIL;
@@ -1247,21 +1246,21 @@ static int	DBpatch_3010043(void)
 
 static int	DBpatch_3010044(void)
 {
-	const ZBX_FIELD	field = {"correlationid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, 0, 0};
+	const zbx_db_field_t	field = {"correlationid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, 0, 0};
 
 	return DBadd_field("problem", &field);
 }
 
 static int	DBpatch_3010045(void)
 {
-	const ZBX_FIELD	field = {"c_eventid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, 0, 0};
+	const zbx_db_field_t	field = {"c_eventid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, 0, 0};
 
 	return DBadd_field("event_recovery", &field);
 }
 
 static int	DBpatch_3010046(void)
 {
-	const ZBX_FIELD	field = {"correlationid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, 0, 0};
+	const zbx_db_field_t	field = {"correlationid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, 0, 0};
 
 	return DBadd_field("event_recovery", &field);
 }
@@ -1273,14 +1272,14 @@ static int	DBpatch_3010047(void)
 
 static int	DBpatch_3010048(void)
 {
-	const ZBX_FIELD	field = {"c_eventid", NULL, "events", "eventid", 0, 0, 0, ZBX_FK_CASCADE_DELETE};
+	const zbx_db_field_t	field = {"c_eventid", NULL, "events", "eventid", 0, 0, 0, ZBX_FK_CASCADE_DELETE};
 
 	return DBadd_foreign_key("event_recovery", 3, &field);
 }
 
 static int	DBpatch_3010049(void)
 {
-	const ZBX_TABLE table =
+	const zbx_db_table_t	table =
 			{"correlation", "correlationid", 0,
 				{
 					{"correlationid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, ZBX_NOTNULL, 0},
@@ -1309,7 +1308,7 @@ static int	DBpatch_3010051(void)
 
 static int	DBpatch_3010052(void)
 {
-	const ZBX_TABLE table =
+	const zbx_db_table_t	table =
 			{"corr_condition", "corr_conditionid", 0,
 				{
 					{"corr_conditionid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, ZBX_NOTNULL, 0},
@@ -1330,14 +1329,15 @@ static int	DBpatch_3010053(void)
 
 static int	DBpatch_3010054(void)
 {
-	const ZBX_FIELD	field = {"correlationid", NULL, "correlation", "correlationid", 0, 0, 0, ZBX_FK_CASCADE_DELETE};
+	const zbx_db_field_t	field = {"correlationid", NULL, "correlation", "correlationid", 0, 0, 0,
+			ZBX_FK_CASCADE_DELETE};
 
 	return DBadd_foreign_key("corr_condition", 1, &field);
 }
 
 static int	DBpatch_3010055(void)
 {
-	const ZBX_TABLE table =
+	const zbx_db_table_t	table =
 			{"corr_condition_tag", "corr_conditionid", 0,
 				{
 					{"corr_conditionid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, ZBX_NOTNULL, 0},
@@ -1352,7 +1352,7 @@ static int	DBpatch_3010055(void)
 
 static int	DBpatch_3010056(void)
 {
-	const ZBX_FIELD	field = {"corr_conditionid", NULL, "corr_condition", "corr_conditionid", 0, 0, 0,
+	const zbx_db_field_t	field = {"corr_conditionid", NULL, "corr_condition", "corr_conditionid", 0, 0, 0,
 			ZBX_FK_CASCADE_DELETE};
 
 	return DBadd_foreign_key("corr_condition_tag", 1, &field);
@@ -1360,7 +1360,7 @@ static int	DBpatch_3010056(void)
 
 static int	DBpatch_3010057(void)
 {
-	const ZBX_TABLE table =
+	const zbx_db_table_t	table =
 			{"corr_condition_group", "corr_conditionid", 0,
 				{
 					{"corr_conditionid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, ZBX_NOTNULL, 0},
@@ -1381,7 +1381,7 @@ static int	DBpatch_3010058(void)
 
 static int	DBpatch_3010059(void)
 {
-	const ZBX_FIELD	field = {"corr_conditionid", NULL, "corr_condition", "corr_conditionid", 0, 0, 0,
+	const zbx_db_field_t	field = {"corr_conditionid", NULL, "corr_condition", "corr_conditionid", 0, 0, 0,
 			ZBX_FK_CASCADE_DELETE};
 
 	return DBadd_foreign_key("corr_condition_group", 1, &field);
@@ -1389,14 +1389,14 @@ static int	DBpatch_3010059(void)
 
 static int	DBpatch_3010060(void)
 {
-	const ZBX_FIELD	field = {"groupid", NULL, "groups", "groupid", 0, 0, 0, 0};
+	const zbx_db_field_t	field = {"groupid", NULL, "groups", "groupid", 0, 0, 0, 0};
 
 	return DBadd_foreign_key("corr_condition_group", 2, &field);
 }
 
 static int	DBpatch_3010061(void)
 {
-	const ZBX_TABLE table =
+	const zbx_db_table_t	table =
 			{"corr_condition_tagpair", "corr_conditionid", 0,
 				{
 					{"corr_conditionid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, ZBX_NOTNULL, 0},
@@ -1412,7 +1412,7 @@ static int	DBpatch_3010061(void)
 
 static int	DBpatch_3010062(void)
 {
-	const ZBX_FIELD	field = {"corr_conditionid", NULL, "corr_condition", "corr_conditionid", 0, 0, 0,
+	const zbx_db_field_t	field = {"corr_conditionid", NULL, "corr_condition", "corr_conditionid", 0, 0, 0,
 			ZBX_FK_CASCADE_DELETE};
 
 	return DBadd_foreign_key("corr_condition_tagpair", 1, &field);
@@ -1420,7 +1420,7 @@ static int	DBpatch_3010062(void)
 
 static int	DBpatch_3010063(void)
 {
-	const ZBX_TABLE table =
+	const zbx_db_table_t	table =
 			{"corr_condition_tagvalue", "corr_conditionid", 0,
 				{
 					{"corr_conditionid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, ZBX_NOTNULL, 0},
@@ -1437,7 +1437,7 @@ static int	DBpatch_3010063(void)
 
 static int	DBpatch_3010064(void)
 {
-	const ZBX_FIELD	field = {"corr_conditionid", NULL, "corr_condition", "corr_conditionid", 0, 0, 0,
+	const zbx_db_field_t	field = {"corr_conditionid", NULL, "corr_condition", "corr_conditionid", 0, 0, 0,
 			ZBX_FK_CASCADE_DELETE};
 
 	return DBadd_foreign_key("corr_condition_tagvalue", 1, &field);
@@ -1445,7 +1445,7 @@ static int	DBpatch_3010064(void)
 
 static int	DBpatch_3010065(void)
 {
-	const ZBX_TABLE table =
+	const zbx_db_table_t	table =
 			{"corr_operation", "corr_operationid", 0,
 				{
 					{"corr_operationid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, ZBX_NOTNULL, 0},
@@ -1466,7 +1466,8 @@ static int	DBpatch_3010066(void)
 
 static int	DBpatch_3010067(void)
 {
-	const ZBX_FIELD	field = {"correlationid", NULL, "correlation", "correlationid", 0, 0, 0, ZBX_FK_CASCADE_DELETE};
+	const zbx_db_field_t	field = {"correlationid", NULL, "correlation", "correlationid", 0, 0, 0,
+			ZBX_FK_CASCADE_DELETE};
 
 	return DBadd_foreign_key("corr_operation", 1, &field);
 }
@@ -1475,7 +1476,7 @@ static int	DBpatch_3010068(void)
 {
 	/* state: 0 - TRIGGER_STATE_NORMAL */
 	/* flags: 2 - ZBX_FLAG_DISCOVERY_PROTOTYPE */
-	if (ZBX_DB_OK <= DBexecute("update triggers set error='',state=0 where flags=2"))
+	if (ZBX_DB_OK <= zbx_db_execute("update triggers set error='',state=0 where flags=2"))
 		return SUCCEED;
 
 	return FAIL;
@@ -1483,7 +1484,7 @@ static int	DBpatch_3010068(void)
 
 static int	DBpatch_3010069(void)
 {
-	const ZBX_TABLE table =
+	const zbx_db_table_t	table =
 			{"task", "taskid", 0,
 				{
 					{"taskid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, ZBX_NOTNULL, 0},
@@ -1498,7 +1499,7 @@ static int	DBpatch_3010069(void)
 
 static int	DBpatch_3010070(void)
 {
-	const ZBX_TABLE table =
+	const zbx_db_table_t	table =
 			{"task_close_problem", "taskid", 0,
 				{
 					{"taskid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, ZBX_NOTNULL, 0},
@@ -1513,35 +1514,35 @@ static int	DBpatch_3010070(void)
 
 static int	DBpatch_3010071(void)
 {
-	const ZBX_FIELD	field = {"taskid", NULL, "task", "taskid", 0, 0, 0, ZBX_FK_CASCADE_DELETE};
+	const zbx_db_field_t	field = {"taskid", NULL, "task", "taskid", 0, 0, 0, ZBX_FK_CASCADE_DELETE};
 
 	return DBadd_foreign_key("task_close_problem", 1, &field);
 }
 
 static int	DBpatch_3010072(void)
 {
-	const ZBX_FIELD	field = {"action", "0", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
+	const zbx_db_field_t	field = {"action", "0", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
 
 	return DBadd_field("acknowledges", &field);
 }
 
 static int	DBpatch_3010073(void)
 {
-	const ZBX_FIELD	field = {"manual_close", "0", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
+	const zbx_db_field_t	field = {"manual_close", "0", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
 
 	return DBadd_field("triggers", &field);
 }
 
 static int	DBpatch_3010074(void)
 {
-	const ZBX_FIELD	field = {"userid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, 0, 0};
+	const zbx_db_field_t	field = {"userid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, 0, 0};
 
 	return DBadd_field("event_recovery", &field);
 }
 
 static int	DBpatch_3010075(void)
 {
-	const ZBX_FIELD	field = {"userid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, 0, 0};
+	const zbx_db_field_t	field = {"userid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, 0, 0};
 
 	return DBadd_field("problem", &field);
 }
@@ -1557,7 +1558,7 @@ static int	DBpatch_3010076(void)
 			"'web.events.trigger.period'"
 		")";
 
-	if (ZBX_DB_OK <= DBexecute("%s", sql))
+	if (ZBX_DB_OK <= zbx_db_execute("%s", sql))
 		return SUCCEED;
 
 	return FAIL;
@@ -1565,54 +1566,54 @@ static int	DBpatch_3010076(void)
 
 static int	DBpatch_3010077(void)
 {
-	const ZBX_FIELD	field = {"name", "", NULL, NULL, 255, ZBX_TYPE_CHAR, ZBX_NOTNULL, 0};
+	const zbx_db_field_t	field = {"name", "", NULL, NULL, 255, ZBX_TYPE_CHAR, ZBX_NOTNULL, 0};
 
 	return DBmodify_field_type("groups", &field, NULL);
 }
 
 static int	DBpatch_3010078(void)
 {
-	const ZBX_FIELD	field = {"name", "", NULL, NULL, 255, ZBX_TYPE_CHAR, ZBX_NOTNULL, 0};
+	const zbx_db_field_t	field = {"name", "", NULL, NULL, 255, ZBX_TYPE_CHAR, ZBX_NOTNULL, 0};
 
 	return DBmodify_field_type("group_prototype", &field, NULL);
 }
 
 static int	DBpatch_3010079(void)
 {
-	DB_ROW			row;
-	DB_RESULT		result;
+	zbx_db_row_t		row;
+	zbx_db_result_t		result;
 	int			ret = FAIL;
 	char			*sql = NULL;
 	size_t			sql_alloc = 0, sql_offset = 0;
 
-	DBbegin_multiple_update(&sql, &sql_alloc, &sql_offset);
+	zbx_db_begin_multiple_update(&sql, &sql_alloc, &sql_offset);
 
-	result = DBselect("select p.eventid,e.clock,e.ns"
+	result = zbx_db_select("select p.eventid,e.clock,e.ns"
 			" from problem p,events e"
 			" where p.eventid=e.eventid"
 				" and p.clock=0");
 
-	while (NULL != (row = DBfetch(result)))
+	while (NULL != (row = zbx_db_fetch(result)))
 	{
 		zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset,
 				"update problem set clock=%s,ns=%s where eventid=%s;\n",
 				row[1], row[2], row[0]);
 
-		if (SUCCEED != DBexecute_overflowed_sql(&sql, &sql_alloc, &sql_offset))
+		if (SUCCEED != zbx_db_execute_overflowed_sql(&sql, &sql_alloc, &sql_offset))
 			goto out;
 	}
 
-	DBend_multiple_update(&sql, &sql_alloc, &sql_offset);
+	zbx_db_end_multiple_update(&sql, &sql_alloc, &sql_offset);
 
 	if (16 < sql_offset)
 	{
-		if (ZBX_DB_OK > DBexecute("%s", sql))
+		if (ZBX_DB_OK > zbx_db_execute("%s", sql))
 			goto out;
 	}
 
 	ret = SUCCEED;
 out:
-	DBfree_result(result);
+	zbx_db_free_result(result);
 	zbx_free(sql);
 
 	return ret;
