@@ -1,27 +1,21 @@
 /*
-** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
-#include "common.h"
-#include "db.h"
 #include "dbupgrade.h"
 
-extern unsigned char	program_type;
+#include "zbxnum.h"
+#include "zbxdbhigh.h"
 
 /*
  * 4.2 development database patches
@@ -31,17 +25,17 @@ extern unsigned char	program_type;
 
 static int	DBpatch_4010001(void)
 {
-	const ZBX_FIELD	field = {"content_type", "1", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
+	const zbx_db_field_t	field = {"content_type", "1", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
 
 	return DBadd_field("media_type", &field);
 }
 
 static int	DBpatch_4010002(void)
 {
-	if (0 == (program_type & ZBX_PROGRAM_TYPE_SERVER))
+	if (0 == (DBget_program_type() & ZBX_PROGRAM_TYPE_SERVER))
 		return SUCCEED;
 
-	if (ZBX_DB_OK > DBexecute("update media_type set content_type=0"))
+	if (ZBX_DB_OK > zbx_db_execute("update media_type set content_type=0"))
 		return FAIL;
 
 	return SUCCEED;
@@ -49,21 +43,21 @@ static int	DBpatch_4010002(void)
 
 static int	DBpatch_4010003(void)
 {
-	const ZBX_FIELD	field = {"error_handler", "0", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
+	const zbx_db_field_t	field = {"error_handler", "0", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
 
 	return DBadd_field("item_preproc", &field);
 }
 
 static int	DBpatch_4010004(void)
 {
-	const ZBX_FIELD	field = {"error_handler_params", "", NULL, NULL, 255, ZBX_TYPE_CHAR, ZBX_NOTNULL, 0};
+	const zbx_db_field_t	field = {"error_handler_params", "", NULL, NULL, 255, ZBX_TYPE_CHAR, ZBX_NOTNULL, 0};
 
 	return DBadd_field("item_preproc", &field);
 }
 
 static int	DBpatch_4010005(void)
 {
-	const ZBX_TABLE table =
+	const zbx_db_table_t	table =
 			{"lld_macro_path", "lld_macro_pathid", 0,
 				{
 					{"lld_macro_pathid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, ZBX_NOTNULL, 0},
@@ -85,31 +79,31 @@ static int	DBpatch_4010006(void)
 
 static int	DBpatch_4010007(void)
 {
-	const ZBX_FIELD	field = {"itemid", NULL, "items", "itemid", 0, 0, 0, ZBX_FK_CASCADE_DELETE};
+	const zbx_db_field_t	field = {"itemid", NULL, "items", "itemid", 0, 0, 0, ZBX_FK_CASCADE_DELETE};
 
 	return DBadd_foreign_key("lld_macro_path", 1, &field);
 }
 
 static int	DBpatch_4010008(void)
 {
-	const ZBX_FIELD	field = {"db_extension", "", NULL, NULL, 32, ZBX_TYPE_CHAR, ZBX_NOTNULL, 0};
+	const zbx_db_field_t	field = {"db_extension", "", NULL, NULL, 32, ZBX_TYPE_CHAR, ZBX_NOTNULL, 0};
 
 	return DBadd_field("config", &field);
 }
 
 static int	DBpatch_4010009(void)
 {
-	const ZBX_TABLE table =
-		{"host_tag", "hosttagid", 0,
-			{
-				{"hosttagid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, ZBX_NOTNULL, 0},
-				{"hostid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, ZBX_NOTNULL, 0},
-				{"tag", "", NULL, NULL, 255, ZBX_TYPE_CHAR, ZBX_NOTNULL, 0},
-				{"value", "", NULL, NULL, 255, ZBX_TYPE_CHAR, ZBX_NOTNULL, 0},
-				{0}
-			},
-			NULL
-		};
+	const zbx_db_table_t	table =
+			{"host_tag", "hosttagid", 0,
+				{
+					{"hosttagid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, ZBX_NOTNULL, 0},
+					{"hostid", NULL, NULL, NULL, 0, ZBX_TYPE_ID, ZBX_NOTNULL, 0},
+					{"tag", "", NULL, NULL, 255, ZBX_TYPE_CHAR, ZBX_NOTNULL, 0},
+					{"value", "", NULL, NULL, 255, ZBX_TYPE_CHAR, ZBX_NOTNULL, 0},
+					{0}
+				},
+				NULL
+			};
 
 	return DBcreate_table(&table);
 }
@@ -121,24 +115,24 @@ static int	DBpatch_4010010(void)
 
 static int	DBpatch_4010011(void)
 {
-	const ZBX_FIELD	field = {"hostid", NULL, "hosts", "hostid", 0, 0, 0, ZBX_FK_CASCADE_DELETE};
+	const zbx_db_field_t	field = {"hostid", NULL, "hosts", "hostid", 0, 0, 0, ZBX_FK_CASCADE_DELETE};
 
 	return DBadd_foreign_key("host_tag", 1, &field);
 }
 
 static int	DBpatch_4010012(void)
 {
-	const ZBX_FIELD	field = {"params", "", NULL, NULL, 0, ZBX_TYPE_SHORTTEXT, ZBX_NOTNULL, 0};
+	const zbx_db_field_t	field = {"params", "", NULL, NULL, 0, ZBX_TYPE_SHORTTEXT, ZBX_NOTNULL, 0};
 
 	return DBmodify_field_type("item_preproc", &field, NULL);
 }
 
 static int	DBpatch_4010013(void)
 {
-	if (0 == (program_type & ZBX_PROGRAM_TYPE_SERVER))
+	if (0 == (DBget_program_type() & ZBX_PROGRAM_TYPE_SERVER))
 		return SUCCEED;
 
-	if (ZBX_DB_OK > DBexecute("update profiles set idx='web.items.filter_groupids'"
+	if (ZBX_DB_OK > zbx_db_execute("update profiles set idx='web.items.filter_groupids'"
 				" where idx='web.items.filter_groupid'"))
 		return FAIL;
 
@@ -147,10 +141,10 @@ static int	DBpatch_4010013(void)
 
 static int	DBpatch_4010014(void)
 {
-	if (0 == (program_type & ZBX_PROGRAM_TYPE_SERVER))
+	if (0 == (DBget_program_type() & ZBX_PROGRAM_TYPE_SERVER))
 		return SUCCEED;
 
-	if (ZBX_DB_OK > DBexecute("update profiles set idx='web.items.filter_hostids'"
+	if (ZBX_DB_OK > zbx_db_execute("update profiles set idx='web.items.filter_hostids'"
 				" where idx='web.items.filter_hostid'"))
 		return FAIL;
 
@@ -159,10 +153,10 @@ static int	DBpatch_4010014(void)
 
 static int	DBpatch_4010015(void)
 {
-	if (0 == (program_type & ZBX_PROGRAM_TYPE_SERVER))
+	if (0 == (DBget_program_type() & ZBX_PROGRAM_TYPE_SERVER))
 		return SUCCEED;
 
-	if (ZBX_DB_OK > DBexecute("update profiles set idx='web.items.filter_inherited'"
+	if (ZBX_DB_OK > zbx_db_execute("update profiles set idx='web.items.filter_inherited'"
 				" where idx='web.items.filter_templated_items'"))
 		return FAIL;
 
@@ -171,10 +165,10 @@ static int	DBpatch_4010015(void)
 
 static int	DBpatch_4010016(void)
 {
-	if (0 == (program_type & ZBX_PROGRAM_TYPE_SERVER))
+	if (0 == (DBget_program_type() & ZBX_PROGRAM_TYPE_SERVER))
 		return SUCCEED;
 
-	if (ZBX_DB_OK > DBexecute("delete from profiles where idx='web.triggers.filter_priority' and value_int='-1'"))
+	if (ZBX_DB_OK > zbx_db_execute("delete from profiles where idx='web.triggers.filter_priority' and value_int='-1'"))
 		return FAIL;
 
 	return SUCCEED;
@@ -182,14 +176,14 @@ static int	DBpatch_4010016(void)
 
 static int	DBpatch_4010017(void)
 {
-	const ZBX_FIELD	field = {"host_source", "1", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
+	const zbx_db_field_t	field = {"host_source", "1", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
 
 	return DBadd_field("dchecks", &field);
 }
 
 static int	DBpatch_4010018(void)
 {
-	const ZBX_FIELD	field = {"name_source", "0", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
+	const zbx_db_field_t	field = {"name_source", "0", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
 
 	return DBadd_field("dchecks", &field);
 }
@@ -211,7 +205,7 @@ static int	DBpatch_4010021(void)
 
 static int	DBpatch_4010022(void)
 {
-	const ZBX_FIELD	field = {"druleid", NULL, "drules", "druleid", 0, 0, 0, ZBX_FK_CASCADE_DELETE};
+	const zbx_db_field_t	field = {"druleid", NULL, "drules", "druleid", 0, 0, 0, ZBX_FK_CASCADE_DELETE};
 
 	return DBadd_foreign_key("dchecks", 1, &field);
 }
@@ -223,33 +217,33 @@ static int	DBpatch_4010023(void)
 
 static int	DBpatch_4010024(void)
 {
-	const ZBX_FIELD	field = {"height", "2", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
+	const zbx_db_field_t	field = {"height", "2", NULL, NULL, 0, ZBX_TYPE_INT, ZBX_NOTNULL, 0};
 
 	return DBmodify_field_type("widget", &field, NULL);
 }
 
 static int	DBpatch_4010025(void)
 {
-	DB_ROW		row;
-	DB_RESULT	result;
+	zbx_db_row_t	row;
+	zbx_db_result_t	result;
 	zbx_uint64_t	nextid;
 
-	if (0 != (program_type & ZBX_PROGRAM_TYPE_SERVER))
+	if (0 != (DBget_program_type() & ZBX_PROGRAM_TYPE_SERVER))
 		return SUCCEED;
 
-	if (ZBX_DB_OK > DBexecute("delete from ids where table_name='proxy_history'"))
+	if (ZBX_DB_OK > zbx_db_execute("delete from ids where table_name='proxy_history'"))
 		return FAIL;
 
-	result = DBselect("select max(id) from proxy_history");
+	result = zbx_db_select("select max(id) from proxy_history");
 
-	if (NULL != (row = DBfetch(result)))
+	if (NULL != (row = zbx_db_fetch(result)))
 		ZBX_DBROW2UINT64(nextid, row[0]);
 	else
 		nextid = 0;
 
-	DBfree_result(result);
+	zbx_db_free_result(result);
 
-	if (0 != nextid && ZBX_DB_OK > DBexecute("insert into ids values ('proxy_history','history_lastid'," ZBX_FS_UI64
+	if (0 != nextid && ZBX_DB_OK > zbx_db_execute("insert into ids values ('proxy_history','history_lastid'," ZBX_FS_UI64
 			")", nextid))
 	{
 		return FAIL;
@@ -260,10 +254,10 @@ static int	DBpatch_4010025(void)
 
 static int	DBpatch_4010026(void)
 {
-	if (0 != (program_type & ZBX_PROGRAM_TYPE_SERVER))
+	if (0 != (DBget_program_type() & ZBX_PROGRAM_TYPE_SERVER))
 		return SUCCEED;
 
-	if (ZBX_DB_OK > DBexecute("update hosts set status=1"))
+	if (ZBX_DB_OK > zbx_db_execute("update hosts set status=1"))
 		return FAIL;
 
 	return SUCCEED;
@@ -271,7 +265,7 @@ static int	DBpatch_4010026(void)
 
 static int	DBpatch_4010027(void)
 {
-	const ZBX_FIELD	field = {"details", "", NULL, NULL, 255, ZBX_TYPE_CHAR, ZBX_NOTNULL, 0};
+	const zbx_db_field_t	field = {"details", "", NULL, NULL, 255, ZBX_TYPE_CHAR, ZBX_NOTNULL, 0};
 
 	return DBadd_field("triggers", &field);
 }
