@@ -30,6 +30,10 @@
 #include "zbxstr.h"
 #include "zbxpoller.h"
 
+#ifndef EVDNS_BASE_INITIALIZE_NAMESERVERS
+#	define EVDNS_BASE_INITIALIZE_NAMESERVERS	1
+#endif
+
 static ZBX_THREAD_LOCAL int log_worker_id;
 
 static int	discovery_async_poller_dns_init(discovery_poller_config_t *poller_config)
@@ -208,7 +212,7 @@ static int	discovery_snmp(discovery_poller_config_t *poller_config, const zbx_dc
 
 	if (SUCCEED != (ret = zbx_async_check_snmp(&item, &result, process_snmp_result, async_result, NULL,
 			poller_config->base, poller_config->dnsbase, poller_config->config_source_ip,
-			ZABBIX_ASYNC_RESOLVE_REVERSE_DNS_YES)))
+			ZABBIX_ASYNC_RESOLVE_REVERSE_DNS_YES, 0)))
 	{
 		if (ZBX_ISSET_MSG(&result))
 			*error = zbx_strdup(*error, *ZBX_GET_MSG_RESULT(&result));
