@@ -372,6 +372,9 @@ static void	async_poller_init(zbx_poller_config_t *poller_config, zbx_thread_pol
 
 	poller_config->config_source_ip = poller_args_in->config_comms->config_source_ip;
 	poller_config->config_timeout = poller_args_in->config_comms->config_timeout;
+	poller_config->config_ssl_ca_location = poller_args_in->config_comms->config_ssl_ca_location;
+	poller_config->config_ssl_cert_location = poller_args_in->config_comms->config_ssl_cert_location;
+	poller_config->config_ssl_key_location = poller_args_in->config_comms->config_ssl_key_location;
 	poller_config->poller_type = poller_args_in->poller_type;
 	poller_config->config_unavailable_delay = poller_args_in->config_unavailable_delay;
 	poller_config->config_unreachable_delay = poller_args_in->config_unreachable_delay;
@@ -576,7 +579,8 @@ ZBX_THREAD_ENTRY(zbx_async_poller_thread, args)
 		zbx_uint32_t	rtc_cmd;
 		unsigned char	*rtc_data;
 
-		if (ZBX_PROCESS_STATE_BUSY == poller_config.state)
+		if (ZBX_PROCESS_STATE_BUSY == poller_config.state &&
+				poller_config.processing < poller_config.config_max_concurrent_checks_per_poller)
 		{
 			zbx_update_selfmon_counter(info, ZBX_PROCESS_STATE_IDLE);
 			poller_config.state = ZBX_PROCESS_STATE_IDLE;
@@ -600,9 +604,9 @@ ZBX_THREAD_ENTRY(zbx_async_poller_thread, args)
 		{
 			zbx_update_env(get_process_type_string(process_type), zbx_time());
 
-			zbx_setproctitle("%s #%d [got %d values, queued %d in 5 sec%s]",
+			zbx_setproctitle("%s #%d [got %d values, queued %d in 5 sec, awaiting %d%s]",
 				get_process_type_string(process_type), process_num, poller_config.processed,
-				poller_config.queued, zbx_vps_monitor_status());
+				poller_config.queued, poller_config.processing, zbx_vps_monitor_status());
 
 			poller_config.processed = 0;
 			poller_config.queued = 0;
