@@ -1,27 +1,21 @@
 /*
-** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
-#include "common.h"
-#include "sysinfo.h"
-#include "log.h"
+#include "zbxsysinfo.h"
+#include "../sysinfo.h"
 
-#define ZBX_DEV_PFX	"/dev/"
+#include "zbxstr.h"
 
 typedef struct
 {
@@ -32,7 +26,7 @@ typedef struct
 }
 zbx_perfstat_t;
 
-int	get_diskstat(const char *devname, zbx_uint64_t *dstat)
+int	zbx_get_diskstat(const char *devname, zbx_uint64_t *dstat)
 {
 	ZBX_UNUSED(devname);
 	ZBX_UNUSED(dstat);
@@ -50,7 +44,7 @@ static int	get_perfstat_io(const char *devname, zbx_perfstat_t *zp, char **error
 		perfstat_id_t	name;
 		perfstat_disk_t	data;
 
-		strscpy(name.name, devname);
+		zbx_strscpy(name.name, devname);
 
 		if (0 < (err = perfstat_disk(&name, &data, sizeof(data), 1)))
 		{
@@ -85,11 +79,12 @@ static int	get_perfstat_io(const char *devname, zbx_perfstat_t *zp, char **error
 	return SYSINFO_RET_FAIL;
 #else
 	*error = zbx_strdup(NULL, "Agent was compiled without support for Perfstat API.");
+
 	return SYSINFO_RET_FAIL;
 #endif
 }
 
-static int	VFS_DEV_READ_BYTES(const char *devname, AGENT_RESULT *result)
+static int	vfs_dev_read_bytes(const char *devname, AGENT_RESULT *result)
 {
 	zbx_perfstat_t	zp;
 	char		*error;
@@ -105,7 +100,7 @@ static int	VFS_DEV_READ_BYTES(const char *devname, AGENT_RESULT *result)
 	return SYSINFO_RET_OK;
 }
 
-static int	VFS_DEV_READ_OPERATIONS(const char *devname, AGENT_RESULT *result)
+static int	vfs_dev_read_operations(const char *devname, AGENT_RESULT *result)
 {
 	zbx_perfstat_t	zp;
 	char		*error;
@@ -121,7 +116,7 @@ static int	VFS_DEV_READ_OPERATIONS(const char *devname, AGENT_RESULT *result)
 	return SYSINFO_RET_OK;
 }
 
-static int	VFS_DEV_WRITE_BYTES(const char *devname, AGENT_RESULT *result)
+static int	vfs_dev_write_bytes(const char *devname, AGENT_RESULT *result)
 {
 	zbx_perfstat_t	zp;
 	char		*error;
@@ -137,7 +132,7 @@ static int	VFS_DEV_WRITE_BYTES(const char *devname, AGENT_RESULT *result)
 	return SYSINFO_RET_OK;
 }
 
-static int	VFS_DEV_WRITE_OPERATIONS(const char *devname, AGENT_RESULT *result)
+static int	vfs_dev_write_operations(const char *devname, AGENT_RESULT *result)
 {
 	zbx_perfstat_t	zp;
 	char		*error;
@@ -153,7 +148,9 @@ static int	VFS_DEV_WRITE_OPERATIONS(const char *devname, AGENT_RESULT *result)
 	return SYSINFO_RET_OK;
 }
 
-int	VFS_DEV_READ(AGENT_REQUEST *request, AGENT_RESULT *result)
+#define ZBX_DEV_PFX	"/dev/"
+
+int	vfs_dev_read(AGENT_REQUEST *request, AGENT_RESULT *result)
 {
 	const char	*devname, *type;
 	int		ret;
@@ -174,9 +171,9 @@ int	VFS_DEV_READ(AGENT_REQUEST *request, AGENT_RESULT *result)
 	type = get_rparam(request, 1);
 
 	if (NULL == type || '\0' == *type || 0 == strcmp(type, "operations"))
-		ret = VFS_DEV_READ_OPERATIONS(devname, result);
+		ret = vfs_dev_read_operations(devname, result);
 	else if (0 == strcmp(type, "bytes"))
-		ret = VFS_DEV_READ_BYTES(devname, result);
+		ret = vfs_dev_read_bytes(devname, result);
 	else
 	{
 		SET_MSG_RESULT(result, zbx_strdup(NULL, "Invalid second parameter."));
@@ -186,7 +183,7 @@ int	VFS_DEV_READ(AGENT_REQUEST *request, AGENT_RESULT *result)
 	return ret;
 }
 
-int	VFS_DEV_WRITE(AGENT_REQUEST *request, AGENT_RESULT *result)
+int	vfs_dev_write(AGENT_REQUEST *request, AGENT_RESULT *result)
 {
 	const char	*devname, *type;
 	int		ret;
@@ -207,9 +204,9 @@ int	VFS_DEV_WRITE(AGENT_REQUEST *request, AGENT_RESULT *result)
 	type = get_rparam(request, 1);
 
 	if (NULL == type || '\0' == *type || 0 == strcmp(type, "operations"))
-		ret = VFS_DEV_WRITE_OPERATIONS(devname, result);
+		ret = vfs_dev_write_operations(devname, result);
 	else if (0 == strcmp(type, "bytes"))
-		ret = VFS_DEV_WRITE_BYTES(devname, result);
+		ret = vfs_dev_write_bytes(devname, result);
 	else
 	{
 		SET_MSG_RESULT(result, zbx_strdup(NULL, "Invalid second parameter."));
@@ -218,3 +215,4 @@ int	VFS_DEV_WRITE(AGENT_REQUEST *request, AGENT_RESULT *result)
 
 	return ret;
 }
+#undef ZBX_DEV_PFX
