@@ -1,25 +1,19 @@
 /*
-** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
-#include "common.h"
-#include "sysinfo.h"
-#include "log.h"
+#include "zbxsysinfo.h"
+#include "../sysinfo.h"
 
 static vm_size_t	pagesize = 0;
 
@@ -49,7 +43,7 @@ static zbx_uint64_t	memsize;
 		return SYSINFO_RET_FAIL;									\
 	}
 
-static int	VM_MEMORY_TOTAL(AGENT_RESULT *result)
+static int	vm_memory_total(AGENT_RESULT *result)
 {
 	ZBX_SYSCTL(memsize);
 
@@ -58,7 +52,7 @@ static int	VM_MEMORY_TOTAL(AGENT_RESULT *result)
 	return SYSINFO_RET_OK;
 }
 
-static int	VM_MEMORY_ACTIVE(AGENT_RESULT *result)
+static int	vm_memory_active(AGENT_RESULT *result)
 {
 	ZBX_HOST_STATISTICS(vm);
 
@@ -67,7 +61,7 @@ static int	VM_MEMORY_ACTIVE(AGENT_RESULT *result)
 	return SYSINFO_RET_OK;
 }
 
-static int	VM_MEMORY_INACTIVE(AGENT_RESULT *result)
+static int	vm_memory_inactive(AGENT_RESULT *result)
 {
 	ZBX_HOST_STATISTICS(vm);
 
@@ -76,7 +70,7 @@ static int	VM_MEMORY_INACTIVE(AGENT_RESULT *result)
 	return SYSINFO_RET_OK;
 }
 
-static int	VM_MEMORY_WIRED(AGENT_RESULT *result)
+static int	vm_memory_wired(AGENT_RESULT *result)
 {
 	ZBX_HOST_STATISTICS(vm);
 
@@ -85,7 +79,7 @@ static int	VM_MEMORY_WIRED(AGENT_RESULT *result)
 	return SYSINFO_RET_OK;
 }
 
-static int	VM_MEMORY_FREE(AGENT_RESULT *result)
+static int	vm_memory_free(AGENT_RESULT *result)
 {
 	ZBX_HOST_STATISTICS(vm);
 
@@ -94,7 +88,7 @@ static int	VM_MEMORY_FREE(AGENT_RESULT *result)
 	return SYSINFO_RET_OK;
 }
 
-static int	VM_MEMORY_USED(AGENT_RESULT *result)
+static int	vm_memory_used(AGENT_RESULT *result)
 {
 	ZBX_HOST_STATISTICS(vm);
 
@@ -103,7 +97,7 @@ static int	VM_MEMORY_USED(AGENT_RESULT *result)
 	return SYSINFO_RET_OK;
 }
 
-static int	VM_MEMORY_PUSED(AGENT_RESULT *result)
+static int	vm_memory_pused(AGENT_RESULT *result)
 {
 	zbx_uint64_t	used;
 
@@ -124,7 +118,7 @@ static int	VM_MEMORY_PUSED(AGENT_RESULT *result)
 	return SYSINFO_RET_OK;
 }
 
-static int	VM_MEMORY_AVAILABLE(AGENT_RESULT *result)
+static int	vm_memory_available(AGENT_RESULT *result)
 {
 	ZBX_HOST_STATISTICS(vm);
 
@@ -133,7 +127,7 @@ static int	VM_MEMORY_AVAILABLE(AGENT_RESULT *result)
 	return SYSINFO_RET_OK;
 }
 
-static int	VM_MEMORY_PAVAILABLE(AGENT_RESULT *result)
+static int	vm_memory_pavailable(AGENT_RESULT *result)
 {
 	zbx_uint64_t	available;
 
@@ -154,7 +148,7 @@ static int	VM_MEMORY_PAVAILABLE(AGENT_RESULT *result)
 	return SYSINFO_RET_OK;
 }
 
-int	VM_MEMORY_SIZE(AGENT_REQUEST *request, AGENT_RESULT *result)
+int	vm_memory_size(AGENT_REQUEST *request, AGENT_RESULT *result)
 {
 	char	*mode;
 	int	ret = SYSINFO_RET_FAIL;
@@ -177,23 +171,23 @@ int	VM_MEMORY_SIZE(AGENT_REQUEST *request, AGENT_RESULT *result)
 	mode = get_rparam(request, 0);
 
 	if (NULL == mode || '\0' == *mode || 0 == strcmp(mode, "total"))
-		ret = VM_MEMORY_TOTAL(result);
+		ret = vm_memory_total(result);
 	else if (0 == strcmp(mode, "active"))
-		ret = VM_MEMORY_ACTIVE(result);
+		ret = vm_memory_active(result);
 	else if (0 == strcmp(mode, "inactive"))
-		ret = VM_MEMORY_INACTIVE(result);
+		ret = vm_memory_inactive(result);
 	else if (0 == strcmp(mode, "wired"))
-		ret = VM_MEMORY_WIRED(result);
+		ret = vm_memory_wired(result);
 	else if (0 == strcmp(mode, "free"))
-		ret = VM_MEMORY_FREE(result);
+		ret = vm_memory_free(result);
 	else if (0 == strcmp(mode, "used"))
-		ret = VM_MEMORY_USED(result);
+		ret = vm_memory_used(result);
 	else if (0 == strcmp(mode, "pused"))
-		ret = VM_MEMORY_PUSED(result);
+		ret = vm_memory_pused(result);
 	else if (0 == strcmp(mode, "available"))
-		ret = VM_MEMORY_AVAILABLE(result);
+		ret = vm_memory_available(result);
 	else if (0 == strcmp(mode, "pavailable"))
-		ret = VM_MEMORY_PAVAILABLE(result);
+		ret = vm_memory_pavailable(result);
 	else
 	{
 		SET_MSG_RESULT(result, zbx_strdup(NULL, "Invalid first parameter."));
