@@ -1,27 +1,22 @@
 /*
-** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 #include "ntp.h"
+#include "../sysinfo.h"
 
-#include "comms.h"
-#include "log.h"
-#include "common.h"
+#include "zbxcomms.h"
+#include "zbxtime.h"
 
 #define NTP_SCALE		4294967296.0	/* 2^32, of course! */
 
@@ -54,18 +49,17 @@ static void	pack_ntp(const ntp_data *data, unsigned char *request, int length)
 	/* Pack the essential data into an NTP packet, bypassing struct layout  */
 	/* and endian problems. Note that it ignores fields irrelevant to SNTP. */
 
-	int	i, k;
-	double	d;
-
 	memset(request, 0, length);
 
 	request[0] = (data->version << 3) | data->mode;
 
-	d = data->transmit / NTP_SCALE;
+	double	d = data->transmit / NTP_SCALE;
 
-	for (i = 0; i < 8; i++)
+	for (int i = 0; i < 8; i++)
 	{
-		if ((k = (int)(d *= 256.0)) >= 256)
+		int	k = (int)(d *= 256.0);
+
+		if (k >= 256)
 			k = 255;
 
 		request[NTP_OFFSET_TRANSMIT + i] = k;
@@ -79,7 +73,7 @@ static int	unpack_ntp(ntp_data *data, const unsigned char *request, const unsign
 	/* Unpack the essential data from an NTP packet, bypassing struct layout */
 	/* and endian problems. Note that it ignores fields irrelevant to SNTP.  */
 
-	int	i, ret = FAIL;
+	int	ret = FAIL;
 	double	d;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
@@ -124,7 +118,7 @@ static int	unpack_ntp(ntp_data *data, const unsigned char *request, const unsign
 	}
 
 	d = 0.0;
-	for (i = 0; i < 8; i++)
+	for (int i = 0; i < 8; i++)
 		d = 256.0 * d + response[NTP_OFFSET_TRANSMIT + i];
 	data->transmit = d / NTP_SCALE;
 
@@ -150,7 +144,7 @@ int	check_ntp(char *host, unsigned short port, int timeout, int *value_int)
 
 	*value_int = 0;
 
-	if (SUCCEED == (ret = zbx_udp_connect(&s, CONFIG_SOURCE_IP, host, port, timeout)))
+	if (SUCCEED == (ret = zbx_udp_connect(&s, sysinfo_get_config_source_ip(), host, port, timeout)))
 	{
 		make_packet(&data);
 
