@@ -1,27 +1,24 @@
 /*
-** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
-#include "common.h"
-#include "sysinfo.h"
-#include "zbxjson.h"
+#include "zbxsysinfo.h"
+#include "../sysinfo.h"
 #include "../common/zbxsysinfo_common.h"
-#include "log.h"
+#include "zbx_sysinfo_kstat.h"
+
+#include "zbxjson.h"
+#include "zbxnum.h"
 
 static int	get_kstat_named_field(const char *name, const char *field, zbx_uint64_t *field_value, char **error)
 {
@@ -87,7 +84,7 @@ clean:
 	return ret;
 }
 
-static int	NET_IF_IN_BYTES(const char *if_name, AGENT_RESULT *result)
+static int	net_if_in_bytes(const char *if_name, AGENT_RESULT *result)
 {
 	zbx_uint64_t	value;
 	char		*error;
@@ -108,7 +105,7 @@ static int	NET_IF_IN_BYTES(const char *if_name, AGENT_RESULT *result)
 	return SYSINFO_RET_OK;
 }
 
-static int	NET_IF_IN_PACKETS(const char *if_name, AGENT_RESULT *result)
+static int	net_if_in_packets(const char *if_name, AGENT_RESULT *result)
 {
 	zbx_uint64_t	value;
 	char		*error;
@@ -129,7 +126,7 @@ static int	NET_IF_IN_PACKETS(const char *if_name, AGENT_RESULT *result)
 	return SYSINFO_RET_OK;
 }
 
-static int	NET_IF_IN_ERRORS(const char *if_name, AGENT_RESULT *result)
+static int	net_if_in_errors(const char *if_name, AGENT_RESULT *result)
 {
 	zbx_uint64_t	value;
 	char		*error;
@@ -145,7 +142,7 @@ static int	NET_IF_IN_ERRORS(const char *if_name, AGENT_RESULT *result)
 	return SYSINFO_RET_OK;
 }
 
-static int	NET_IF_OUT_BYTES(const char *if_name, AGENT_RESULT *result)
+static int	net_if_out_bytes(const char *if_name, AGENT_RESULT *result)
 {
 	zbx_uint64_t	value;
 	char		*error;
@@ -166,7 +163,7 @@ static int	NET_IF_OUT_BYTES(const char *if_name, AGENT_RESULT *result)
 	return SYSINFO_RET_OK;
 }
 
-static int	NET_IF_OUT_PACKETS(const char *if_name, AGENT_RESULT *result)
+static int	net_if_out_packets(const char *if_name, AGENT_RESULT *result)
 {
 	zbx_uint64_t	value;
 	char		*error;
@@ -187,7 +184,7 @@ static int	NET_IF_OUT_PACKETS(const char *if_name, AGENT_RESULT *result)
 	return SYSINFO_RET_OK;
 }
 
-static int	NET_IF_OUT_ERRORS(const char *if_name, AGENT_RESULT *result)
+static int	net_if_out_errors(const char *if_name, AGENT_RESULT *result)
 {
 	zbx_uint64_t	value;
 	char		*error;
@@ -203,7 +200,7 @@ static int	NET_IF_OUT_ERRORS(const char *if_name, AGENT_RESULT *result)
 	return SYSINFO_RET_OK;
 }
 
-static int	NET_IF_TOTAL_BYTES(const char *if_name, AGENT_RESULT *result)
+static int	net_if_total_bytes(const char *if_name, AGENT_RESULT *result)
 {
 	zbx_uint64_t	value_in, value_out;
 	char		*error;
@@ -226,7 +223,7 @@ static int	NET_IF_TOTAL_BYTES(const char *if_name, AGENT_RESULT *result)
 	return SYSINFO_RET_OK;
 }
 
-static int	NET_IF_TOTAL_PACKETS(const char *if_name, AGENT_RESULT *result)
+static int	net_if_total_packets(const char *if_name, AGENT_RESULT *result)
 {
 	zbx_uint64_t	value_in, value_out;
 	char		*error;
@@ -249,7 +246,7 @@ static int	NET_IF_TOTAL_PACKETS(const char *if_name, AGENT_RESULT *result)
 	return SYSINFO_RET_OK;
 }
 
-static int	NET_IF_TOTAL_ERRORS(const char *if_name, AGENT_RESULT *result)
+static int	net_if_total_errors(const char *if_name, AGENT_RESULT *result)
 {
 	zbx_uint64_t	value_in, value_out;
 	char		*error;
@@ -266,7 +263,7 @@ static int	NET_IF_TOTAL_ERRORS(const char *if_name, AGENT_RESULT *result)
 	return SYSINFO_RET_OK;
 }
 
-int	NET_IF_COLLISIONS(AGENT_REQUEST *request, AGENT_RESULT *result)
+int	net_if_collisions(AGENT_REQUEST *request, AGENT_RESULT *result)
 {
 	zbx_uint64_t	value;
 	char		*if_name, *error;
@@ -296,7 +293,7 @@ int	NET_IF_COLLISIONS(AGENT_REQUEST *request, AGENT_RESULT *result)
 	return SYSINFO_RET_OK;
 }
 
-int	NET_TCP_LISTEN(AGENT_REQUEST *request, AGENT_RESULT *result)
+int	net_tcp_listen(AGENT_REQUEST *request, AGENT_RESULT *result)
 {
 	char		*port_str, command[64];
 	unsigned short	port;
@@ -310,7 +307,7 @@ int	NET_TCP_LISTEN(AGENT_REQUEST *request, AGENT_RESULT *result)
 
 	port_str = get_rparam(request, 0);
 
-	if (NULL == port_str || SUCCEED != is_ushort(port_str, &port))
+	if (NULL == port_str || SUCCEED != zbx_is_ushort(port_str, &port))
 	{
 		SET_MSG_RESULT(result, zbx_strdup(NULL, "Invalid first parameter."));
 		return SYSINFO_RET_FAIL;
@@ -318,7 +315,7 @@ int	NET_TCP_LISTEN(AGENT_REQUEST *request, AGENT_RESULT *result)
 
 	zbx_snprintf(command, sizeof(command), "netstat -an -P tcp | grep '\\.%hu[^.].*LISTEN' | wc -l", port);
 
-	if (SYSINFO_RET_FAIL == (res = EXECUTE_INT(command, result)))
+	if (SYSINFO_RET_FAIL == (res = execute_int(command, result, request->timeout)))
 		return res;
 
 	if (1 < result->ui64)
@@ -327,7 +324,7 @@ int	NET_TCP_LISTEN(AGENT_REQUEST *request, AGENT_RESULT *result)
 	return res;
 }
 
-int	NET_UDP_LISTEN(AGENT_REQUEST *request, AGENT_RESULT *result)
+int	net_udp_listen(AGENT_REQUEST *request, AGENT_RESULT *result)
 {
 	char		*port_str, command[64];
 	unsigned short	port;
@@ -341,7 +338,7 @@ int	NET_UDP_LISTEN(AGENT_REQUEST *request, AGENT_RESULT *result)
 
 	port_str = get_rparam(request, 0);
 
-	if (NULL == port_str || SUCCEED != is_ushort(port_str, &port))
+	if (NULL == port_str || SUCCEED != zbx_is_ushort(port_str, &port))
 	{
 		SET_MSG_RESULT(result, zbx_strdup(NULL, "Invalid first parameter."));
 		return SYSINFO_RET_FAIL;
@@ -349,7 +346,7 @@ int	NET_UDP_LISTEN(AGENT_REQUEST *request, AGENT_RESULT *result)
 
 	zbx_snprintf(command, sizeof(command), "netstat -an -P udp | grep '\\.%hu[^.].*Idle' | wc -l", port);
 
-	if (SYSINFO_RET_FAIL == (res = EXECUTE_INT(command, result)))
+	if (SYSINFO_RET_FAIL == (res = execute_int(command, result, request->timeout)))
 		return res;
 
 	if (1 < result->ui64)
@@ -358,7 +355,7 @@ int	NET_UDP_LISTEN(AGENT_REQUEST *request, AGENT_RESULT *result)
 	return res;
 }
 
-int	NET_IF_IN(AGENT_REQUEST *request, AGENT_RESULT *result)
+int	net_if_in(AGENT_REQUEST *request, AGENT_RESULT *result)
 {
 	char	*if_name, *mode;
 	int	ret;
@@ -379,11 +376,11 @@ int	NET_IF_IN(AGENT_REQUEST *request, AGENT_RESULT *result)
 	}
 
 	if (NULL == mode || '\0' == *mode || 0 == strcmp(mode, "bytes"))
-		ret = NET_IF_IN_BYTES(if_name, result);
+		ret = net_if_in_bytes(if_name, result);
 	else if (0 == strcmp(mode, "packets"))
-		ret = NET_IF_IN_PACKETS(if_name, result);
+		ret = net_if_in_packets(if_name, result);
 	else if (0 == strcmp(mode, "errors"))
-		ret = NET_IF_IN_ERRORS(if_name, result);
+		ret = net_if_in_errors(if_name, result);
 	else
 	{
 		SET_MSG_RESULT(result, zbx_strdup(NULL, "Invalid second parameter."));
@@ -393,7 +390,7 @@ int	NET_IF_IN(AGENT_REQUEST *request, AGENT_RESULT *result)
 	return ret;
 }
 
-int	NET_IF_OUT(AGENT_REQUEST *request, AGENT_RESULT *result)
+int	net_if_out(AGENT_REQUEST *request, AGENT_RESULT *result)
 {
 	char	*if_name, *mode;
 	int	ret;
@@ -414,11 +411,11 @@ int	NET_IF_OUT(AGENT_REQUEST *request, AGENT_RESULT *result)
 	}
 
 	if (NULL == mode || '\0' == *mode || 0 == strcmp(mode, "bytes"))
-		ret = NET_IF_OUT_BYTES(if_name, result);
+		ret = net_if_out_bytes(if_name, result);
 	else if (0 == strcmp(mode, "packets"))
-		ret = NET_IF_OUT_PACKETS(if_name, result);
+		ret = net_if_out_packets(if_name, result);
 	else if (0 == strcmp(mode, "errors"))
-		ret = NET_IF_OUT_ERRORS(if_name, result);
+		ret = net_if_out_errors(if_name, result);
 	else
 	{
 		SET_MSG_RESULT(result, zbx_strdup(NULL, "Invalid second parameter."));
@@ -428,7 +425,7 @@ int	NET_IF_OUT(AGENT_REQUEST *request, AGENT_RESULT *result)
 	return ret;
 }
 
-int	NET_IF_TOTAL(AGENT_REQUEST *request, AGENT_RESULT *result)
+int	net_if_total(AGENT_REQUEST *request, AGENT_RESULT *result)
 {
 	char	*if_name, *mode;
 	int	ret;
@@ -449,11 +446,11 @@ int	NET_IF_TOTAL(AGENT_REQUEST *request, AGENT_RESULT *result)
 	}
 
 	if (NULL == mode || '\0' == *mode || 0 == strcmp(mode, "bytes"))
-		ret = NET_IF_TOTAL_BYTES(if_name, result);
+		ret = net_if_total_bytes(if_name, result);
 	else if (0 == strcmp(mode, "packets"))
-		ret = NET_IF_TOTAL_PACKETS(if_name, result);
+		ret = net_if_total_packets(if_name, result);
 	else if (0 == strcmp(mode, "errors"))
-		ret = NET_IF_TOTAL_ERRORS(if_name, result);
+		ret = net_if_total_errors(if_name, result);
 	else
 	{
 		SET_MSG_RESULT(result, zbx_strdup(NULL, "Invalid second parameter."));
@@ -463,7 +460,7 @@ int	NET_IF_TOTAL(AGENT_REQUEST *request, AGENT_RESULT *result)
 	return ret;
 }
 
-int	NET_IF_DISCOVERY(AGENT_REQUEST *request, AGENT_RESULT *result)
+int	net_if_discovery(AGENT_REQUEST *request, AGENT_RESULT *result)
 {
 	struct if_nameindex	*ni;
 	struct zbx_json		j;
