@@ -47,6 +47,88 @@ typedef struct
 }
 event_hostinfo_node_t;
 
+static zbx_hashset_t	evt_msg_strpool;
+
+/******************************************************************************
+ *                                                                            *
+ * Purpose: initialization of strpool resources                               *
+ *                                                                            *
+ ******************************************************************************/
+static void	evt_msg_strpool_init(void)
+{
+	zbx_hashset_create(&evt_msg_strpool, 100, vmware_strpool_hash_func, vmware_strpool_compare_func);
+}
+
+/******************************************************************************
+ *                                                                            *
+ * Purpose: release of strpool resources                                      *
+ *                                                                            *
+ ******************************************************************************/
+static void	evt_msg_strpool_destroy(void)
+{
+	zbx_hashset_destroy(&evt_msg_strpool);
+}
+
+/******************************************************************************
+ *                                                                            *
+ * Purpose: frees resources allocated to store event message in strpool       *
+ *                                                                            *
+ ******************************************************************************/
+static void	evt_msg_strpool_strfree(char *str, zbx_uint64_t *strpool_sz)
+{
+	zbx_uint64_t	len;
+
+	vmware_strpool_strfree(str, &evt_msg_strpool, &len);
+
+	if (NULL != strpool_sz && 0 < len)
+		*strpool_sz -= zbx_shmem_required_chunk_size(len);
+}
+
+/******************************************************************************
+ *                                                                            *
+ * Purpose: store event message in strpool                                    *
+ *                                                                            *
+ ******************************************************************************/
+static char	*evt_msg_strpool_strdup(const char *str, zbx_uint64_t *strpool_sz)
+{
+	char		*strdup;
+	zbx_uint64_t	len;
+
+	strdup = vmware_strpool_strdup(str, &evt_msg_strpool, &len);
+
+	if (NULL != strpool_sz && 0 < len)
+		*strpool_sz += zbx_shmem_required_chunk_size(len);
+
+	return strdup;
+}
+
+/******************************************************************************
+ *                                                                            *
+ * Purpose: compute common size of memory for evt strpool and shmem strpool   *
+ *                                                                            *
+ ******************************************************************************/
+static zbx_uint64_t	vmware_evt_strpool_overlap_mem(void)
+{
+	void			*ptr;
+	zbx_hashset_iter_t	iter;
+	zbx_uint64_t		common_sz = 0;
+
+	zbx_hashset_iter_reset(&evt_msg_strpool, &iter);
+
+	while (NULL != (ptr = zbx_hashset_iter_next(&iter)))
+	{
+		const char	*str = (char *)ptr + REFCOUNT_FIELD_SIZE;
+
+		if (FAIL == vmware_shared_strsearch(str))
+			continue;
+
+		common_sz += zbx_shmem_required_chunk_size(strlen(str) +
+				REFCOUNT_FIELD_SIZE + 1 + ZBX_HASHSET_ENTRY_OFFSET);
+	}
+
+	return common_sz;
+}
+
 /******************************************************************************
  *                                                                            *
  * Purpose: frees resources allocated to store vmware event                   *
@@ -56,10 +138,23 @@ event_hostinfo_node_t;
  ******************************************************************************/
 void	vmware_event_free(zbx_vmware_event_t *event)
 {
-	evt_msg_strpool_strfree(event->message);
+	evt_msg_strpool_strfree(event->message, NULL);
 	zbx_free(event);
 }
 
+/******************************************************************************
+ *                                                                            *
+ * Purpose: compute full shared memory size of vmware event vector            *
+ *                                                                            *
+ * Parameters: events - [IN] vmware event vector                              *
+ *                                                                            *
+ ******************************************************************************/
+static zbx_uint64_t	vmware_service_evt_vector_memsize(zbx_vector_vmware_event_ptr_t *events)
+{
+	return zbx_vmware_get_evt_req_chunk_sz() * events->values_num +
+			zbx_shmem_required_chunk_size(events->values_alloc * sizeof(zbx_vmware_event_t*));
+}
+
 /******************************************************************************
  *                                                                            *
  * Purpose: gets map of severity and event type                               *
@@ -160,6 +255,7 @@ int	vmware_service_get_evt_severity(zbx_vmware_service_t *service, CURL *easyhan
 clean:
 	xmlXPathFreeObject(xpathObj);
 	xmlXPathFreeContext(xpathCtx);
+	zbx_xml_doc_free(doc);
 out:
 	zabbix_log(LOG_LEVEL_DEBUG, "End of %s() evt_severities:%d", __func__, evt_severities->values_num);
 
@@ -173,6 +269,7 @@ out:
  *                                                                            *
  * Parameters: service       - [IN] vmware service                            *
  *             easyhandle    - [IN] CURL handle                               *
+ *             evt_severity  - [IN] event severities                          *
  *             event_session - [OUT] pointer to output variable               *
  *             error         - [OUT] error message in case of failure         *
  *                                                                            *
@@ -181,7 +278,7 @@ out:
  *                                                                            *
  ******************************************************************************/
 static int	vmware_service_get_event_session(const zbx_vmware_service_t *service, CURL *easyhandle,
-		char **event_session, char **error)
+		const unsigned char evt_severity, char **event_session, char **error)
 {
 #	define ZBX_POST_VMWARE_CREATE_EVENT_COLLECTOR				\
 		ZBX_POST_VSPHERE_HEADER						\
@@ -204,7 +301,7 @@ static int	vmware_service_get_event_session(const zbx_vmware_service_t *service,
 
 	for (size_t i = 0; i < ARRSIZE(levels); i++)
 	{
-		if (0 != ((1 << i) & service->eventlog.severity))
+		if (0 != ((1 << i) & evt_severity))
 		{
 			zbx_snprintf_alloc(&filter, &alloc_len, &offset, ZBX_POST_VMWARE_EVENT_FILTER_SPEC_CATEGORY,
 					levels[i]);
@@ -227,7 +324,7 @@ static int	vmware_service_get_event_session(const zbx_vmware_service_t *service,
 
 	ret = SUCCEED;
 out:
-	zbx_xml_free_doc(doc);
+	zbx_xml_doc_free(doc);
 	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s event_session:'%s'", __func__, zbx_result_string(ret),
 			ZBX_NULL2EMPTY_STR(*event_session));
 
@@ -439,23 +536,23 @@ out:
  *             xml_event      - [IN] xml node and id of parsed event          *
  *             xdoc           - [IN] xml document with eventlog records       *
  *             evt_severities - [IN] dictionary of severity for event types   *
- *             alloc_sz       - [OUT] allocated memory size for events        *
+ *             strpool_sz     - [OUT] estimated shared memory size for events *
  *                                                                            *
  * Return value: SUCCEED - operation has completed successfully               *
  *               FAIL    - operation has failed                               *
  *                                                                            *
  ******************************************************************************/
 static int	vmware_service_put_event_data(zbx_vector_vmware_event_ptr_t *events, zbx_id_xmlnode_t xml_event,
-		xmlDoc *xdoc, const zbx_hashset_t *evt_severities, zbx_uint64_t *alloc_sz)
+		xmlDoc *xdoc, const zbx_hashset_t *evt_severities, zbx_uint64_t *strpool_sz)
 {
-#define ZBX_HOSTINFO_NODES_DATACENTER		0x01
-#define ZBX_HOSTINFO_NODES_COMPRES		0x02
-#define ZBX_HOSTINFO_NODES_HOST			0x04
-#define ZBX_HOSTINFO_NODES_VM			0x08
-#define ZBX_HOSTINFO_NODES_DS			0x10
-#define ZBX_HOSTINFO_NODES_NET			0x20
-#define ZBX_HOSTINFO_NODES_DVS			0x40
-#define ZBX_HOSTINFO_NODES_MASK_ALL									\
+#	define ZBX_HOSTINFO_NODES_DATACENTER		0x01
+#	define ZBX_HOSTINFO_NODES_COMPRES		0x02
+#	define ZBX_HOSTINFO_NODES_HOST			0x04
+#	define ZBX_HOSTINFO_NODES_VM			0x08
+#	define ZBX_HOSTINFO_NODES_DS			0x10
+#	define ZBX_HOSTINFO_NODES_NET			0x20
+#	define ZBX_HOSTINFO_NODES_DVS			0x40
+#	define ZBX_HOSTINFO_NODES_MASK_ALL									\
 		(ZBX_HOSTINFO_NODES_DATACENTER | ZBX_HOSTINFO_NODES_COMPRES | ZBX_HOSTINFO_NODES_HOST | \
 		ZBX_HOSTINFO_NODES_VM | ZBX_HOSTINFO_NODES_DS | ZBX_HOSTINFO_NODES_NET | ZBX_HOSTINFO_NODES_DVS)
 
@@ -468,7 +565,6 @@ static int	vmware_service_put_event_data(zbx_vector_vmware_event_ptr_t *events,
 	char				*message, *ip, *type, *username, *info;
 	int				nodes_det = 0;
 	unsigned int			i;
-	zbx_uint64_t			sz;
 	static event_hostinfo_node_t	host_nodes[] =
 	{
 		{ ZBX_XPATH_EVT_INFO("datacenter"),		ZBX_HOSTINFO_NODES_DATACENTER,	NULL },
@@ -582,25 +678,22 @@ static int	vmware_service_put_event_data(zbx_vector_vmware_event_ptr_t *events,
 	event = (zbx_vmware_event_t *)zbx_malloc(event, sizeof(zbx_vmware_event_t));
 	event->key = xml_event.id;
 	event->timestamp = xml_event.created_time;
-	event->message = evt_msg_strpool_strdup(message, &sz);
+	event->message = evt_msg_strpool_strdup(message, strpool_sz);
 	zbx_free(message);
 	zbx_vector_vmware_event_ptr_append(events, event);
 
-	if (0 < sz)
-		*alloc_sz += zbx_shmem_required_chunk_size(sz);
-
 	return SUCCEED;
-#undef ZBX_HOSTINFO_NODES_DATACENTER
-#undef ZBX_HOSTINFO_NODES_COMPRES
-#undef ZBX_HOSTINFO_NODES_HOST
-#undef ZBX_HOSTINFO_NODES_VM
-#undef ZBX_HOSTINFO_NODES_DS
-#undef ZBX_HOSTINFO_NODES_NET
-#undef ZBX_HOSTINFO_NODES_DVS
-#undef ZBX_HOSTINFO_NODES_MASK_ALL
 
-#	undef	ZBX_XPATH_EVT_INFO
-#	undef	ZBX_XPATH_EVT_ARGUMENT
+#	undef ZBX_HOSTINFO_NODES_DATACENTER
+#	undef ZBX_HOSTINFO_NODES_COMPRES
+#	undef ZBX_HOSTINFO_NODES_HOST
+#	undef ZBX_HOSTINFO_NODES_VM
+#	undef ZBX_HOSTINFO_NODES_DS
+#	undef ZBX_HOSTINFO_NODES_NET
+#	undef ZBX_HOSTINFO_NODES_DVS
+#	undef ZBX_HOSTINFO_NODES_MASK_ALL
+#	undef ZBX_XPATH_EVT_INFO
+#	undef ZBX_XPATH_EVT_ARGUMENT
 }
 
 /******************************************************************************
@@ -643,22 +736,23 @@ static time_t	vmware_service_parse_event_ts(xmlDoc *doc, xmlNode *node, zbx_uint
  *                                                                            *
  * Purpose: parses multiple events data                                       *
  *                                                                            *
- * Parameters: events     - [IN/OUT] array of parsed events                   *
- *             last_key   - [IN] key of last parsed event                     *
- *             last_ts    - [IN] the timestamp of last parsed event           *
- *             is_prop    - [IN] read events from RetrieveProperties xml      *
- *             xdoc       - [IN] xml document with eventlog records           *
- *             eventlog   - [IN] VMware event log state                       *
- *             alloc_sz   - [OUT] allocated memory size for events            *
- *             node_count - [OUT] count of xml event nodes                    *
- *             skip_old   - [OUT] detected event key reset                    *
+ * Parameters: events       - [IN/OUT] array of parsed events                 *
+ *             last_key     - [IN] key of last parsed event                   *
+ *             last_ts      - [IN] the timestamp of last parsed event         *
+ *             is_prop      - [IN] read events from RetrieveProperties xml    *
+ *             xdoc         - [IN] xml document with eventlog records         *
+ *             eventlog     - [IN] VMware event log state                     *
+ *             evt_severity - [IN] event severities                           *
+ *             strpool_sz   - [OUT] estimated shared memory size for events   *
+ *             node_count   - [OUT] count of xml event nodes                  *
+ *             skip_old     - [OUT] detected event key reset                  *
  *                                                                            *
  * Return value: count of events successfully parsed                          *
  *                                                                            *
  ******************************************************************************/
 static int	vmware_service_parse_event_data(zbx_vector_vmware_event_ptr_t *events, zbx_uint64_t last_key,
 		time_t last_ts, const int is_prop, xmlDoc *xdoc, const zbx_vmware_eventlog_state_t *eventlog,
-		zbx_uint64_t *alloc_sz, int *node_count, unsigned char *skip_old)
+		const unsigned char evt_severity, zbx_uint64_t *strpool_sz, int *node_count, unsigned char *skip_old)
 {
 #	define LAST_KEY(evs)	(evs->values[evs->values_num - 1]->key)
 
@@ -670,13 +764,17 @@ static int	vmware_service_parse_event_data(zbx_vector_vmware_event_ptr_t *events
 	xmlNodeSetPtr		nodeset;
 	static int		is_clear = 0;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s() last_key:" ZBX_FS_UI64, __func__, last_key);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s() last_key:" ZBX_FS_UI64 " events:%d memory:" ZBX_FS_UI64, __func__,
+			last_key, events->values_num, *strpool_sz + vmware_service_evt_vector_memsize(events));
 
 	xpathCtx = xmlXPathNewContext(xdoc);
 	zbx_vector_id_xmlnode_create(&ids);
 
+	if (NULL != node_count)
+		*node_count = 0;
+
 	if (NULL == (xpathObj = xmlXPathEvalExpression((const xmlChar *)(0 == is_prop ? "/*/*/*"
-			ZBX_XPATH_LN("returnval") : "/*/*/*" ZBX_XPATH_LN("returnval") "/*/*/*"ZBX_XPATH_LN("Event")),
+			ZBX_XPATH_LN("returnval") : "/*/*/*" ZBX_XPATH_LN("returnval") "/*/*/*" ZBX_XPATH_LN("Event")),
 			xpathCtx)))
 	{
 		zabbix_log(LOG_LEVEL_DEBUG, "Cannot make evenlog list parsing query.");
@@ -685,9 +783,6 @@ static int	vmware_service_parse_event_data(zbx_vector_vmware_event_ptr_t *events
 
 	if (0 != xmlXPathNodeSetIsEmpty(xpathObj->nodesetval))
 	{
-		if (NULL != node_count)
-			*node_count = 0;
-
 		zabbix_log(LOG_LEVEL_DEBUG, "Cannot find items in evenlog list.");
 		goto clean;
 	}
@@ -711,9 +806,13 @@ static int	vmware_service_parse_event_data(zbx_vector_vmware_event_ptr_t *events
 
 		key = (unsigned int) atoi(value);
 
-		if (0 == key && 0 == isdigit(value[('-' == *value || '+' == *value) ? 1 : 0 ]))
+		if (0 == key)
 		{
-			zabbix_log(LOG_LEVEL_TRACE, "skipping eventlog key '%s', not a number", value);
+			if (0 == isdigit(value[('-' == *value || '+' == *value) ? 1 : 0 ]))
+				zabbix_log(LOG_LEVEL_TRACE, "skipping eventlog key '%s', not a number", value);
+			else
+				zabbix_log(LOG_LEVEL_TRACE, "skipping empty eventlog key");
+
 			zbx_free(value);
 			continue;
 		}
@@ -724,7 +823,7 @@ static int	vmware_service_parse_event_data(zbx_vector_vmware_event_ptr_t *events
 
 		if (key <= last_key)
 		{
-			if (xml_event.created_time <= last_ts)
+			if (xml_event.created_time <= last_ts || 0 != events->values_num + ids.values_num)
 			{
 				zabbix_log(LOG_LEVEL_TRACE, "skipping event key '" ZBX_FS_UI64 "', has been processed",
 						key);
@@ -746,7 +845,7 @@ static int	vmware_service_parse_event_data(zbx_vector_vmware_event_ptr_t *events
 	if (0 != ids.values_num)
 	{
 		zbx_vector_id_xmlnode_sort(&ids, ZBX_DEFAULT_UINT64_COMPARE_FUNC);
-		zbx_vector_vmware_event_ptr_reserve(events, (size_t)(ids.values_num + events->values_alloc));
+		zbx_vector_vmware_event_ptr_reserve(events, (size_t)(ids.values_num + events->values_num));
 
 		/* validate that last event from "latestPage" is connected with first event from ReadPreviousEvents */
 		if (0 != events->values_num && LAST_KEY(events) != ids.values[ids.values_num -1].id + 1)
@@ -754,12 +853,15 @@ static int	vmware_service_parse_event_data(zbx_vector_vmware_event_ptr_t *events
 			zabbix_log(LOG_LEVEL_DEBUG, "%s() events:%d is_clear:%d id gap:%d severity:%d", __func__,
 					events->values_num, is_clear,
 					(int)(LAST_KEY(events) - (ids.values[ids.values_num -1].id + 1)),
-					(int)eventlog->severity);
+					(int)evt_severity);
 
 			/* if sequence of events is not continuous, ignore events from "latestPage" property */
 			/* except when events are filtered by severity */
-			if (0 != is_clear && 0 == eventlog->severity)
+			if (0 != is_clear && 0 == evt_severity)
+			{
 				zbx_vector_vmware_event_ptr_clear_ext(events, vmware_event_free);
+				*strpool_sz = 0;
+			}
 		}
 
 		/* we are reading "scrollable views" in reverse chronological order, */
@@ -767,7 +869,7 @@ static int	vmware_service_parse_event_data(zbx_vector_vmware_event_ptr_t *events
 		for (int i = ids.values_num - 1; i >= 0; i--)
 		{
 			if (SUCCEED == vmware_service_put_event_data(events, ids.values[i], xdoc,
-					&eventlog->evt_severities, alloc_sz))
+					&eventlog->evt_severities, strpool_sz))
 			{
 				parsed_num++;
 			}
@@ -777,12 +879,15 @@ static int	vmware_service_parse_event_data(zbx_vector_vmware_event_ptr_t *events
 	{
 		zabbix_log(LOG_LEVEL_DEBUG, "%s() events:%d is_clear:%d last_key id gap:%d severity:%d", __func__,
 				events->values_num, is_clear, (int)(LAST_KEY(events) - (last_key + 1)),
-				(int)eventlog->severity);
+				(int)evt_severity);
 
 		/* if sequence of events is not continuous, ignore events from "latestPage" property */
 		/* except when events are filtered by severity */
-		if (0 != is_clear && 0 == eventlog->severity)
+		if (0 != is_clear && 0 == evt_severity)
+		{
 			zbx_vector_vmware_event_ptr_clear_ext(events, vmware_event_free);
+			*strpool_sz = 0;
+		}
 	}
 clean:
 	zbx_vector_id_xmlnode_destroy(&ids);
@@ -790,7 +895,8 @@ clean:
 	xmlXPathFreeContext(xpathCtx);
 	is_clear = is_prop;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s() parsed:%d", __func__, parsed_num);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s() parsed:%d memory:" ZBX_FS_UI64, __func__, parsed_num,
+			*strpool_sz + vmware_service_evt_vector_memsize(events));
 
 	return parsed_num;
 
@@ -799,22 +905,53 @@ clean:
 
 /******************************************************************************
  *                                                                            *
- * Parameters: service    - [IN] vmware service                               *
- *             easyhandle - [IN] CURL handle                                  *
- *             last_key   - [IN] ID of last processed event                   *
- *             last_ts    - [IN] the create time of last processed event      *
- *             skip_old   - [IN/OUT] reset last_key of event                  *
- *             events     - [OUT] pointer to output variable                  *
- *             alloc_sz   - [OUT] allocated memory size for events            *
- *             error      - [OUT] error message in case of failure            *
+ * Purpose: removing NEW events from "head" of vector                         *
+ *                                                                            *
+ * Parameters: max_mem    - [IN] available memory size                        *
+ *             strpool_sz - [IN/OUT] allocated memory size for events         *
+ *             events     - [IN/OUT] pointer to output variable               *
+ *                                                                            *
+ ******************************************************************************/
+static	void vmware_service_clear_event_data_mem(const zbx_uint64_t max_mem, zbx_uint64_t *strpool_sz,
+		zbx_vector_vmware_event_ptr_t *events)
+{
+	int	events_num = events->values_num;
+
+	while(0 != events->values_num && max_mem < *strpool_sz + vmware_service_evt_vector_memsize(events))
+	{
+		evt_msg_strpool_strfree(events->values[events_num - events->values_num]->message, strpool_sz);
+		zbx_free(events->values[events_num - events->values_num]);
+		events->values_num--;
+	}
+
+	if (0 != events->values_num)
+	{
+		memmove(events->values, &events->values[events_num - events->values_num],
+				sizeof(zbx_vmware_event_t *) * (size_t)events->values_num);
+	}
+}
+
+/******************************************************************************
+ *                                                                            *
+ * Parameters: service       - [IN] vmware service                            *
+ *             easyhandle    - [IN] CURL handle                               *
+ *             last_key      - [IN] ID of last processed event                *
+ *             last_ts       - [IN] the create time of last processed event   *
+ *             shmem_free_sz - [IN] free size of shared memory                *
+ *             evt_severity  - [IN] event severities                          *
+ *             skip_old      - [IN/OUT] reset last_key of event               *
+ *             events        - [OUT] pointer to output variable               *
+ *             strpool_sz    - [OUT] allocated memory size for events         *
+ *             error         - [OUT] error message in case of failure         *
  *                                                                            *
  * Return value: SUCCEED - operation has completed successfully               *
  *               FAIL    - operation has failed                               *
  *                                                                            *
  ******************************************************************************/
 static int	vmware_service_get_event_data(const zbx_vmware_service_t *service, CURL *easyhandle,
-		zbx_uint64_t last_key, time_t last_ts, unsigned char *skip_old, zbx_vector_vmware_event_ptr_t *events,
-		zbx_uint64_t *alloc_sz, char **error)
+		const zbx_uint64_t last_key, const time_t last_ts, const zbx_uint64_t shmem_free_sz,
+		const unsigned char evt_severity, unsigned char *skip_old, zbx_vector_vmware_event_ptr_t *events,
+		zbx_uint64_t *strpool_sz, char **error)
 {
 #	define ATTEMPTS_NUM	4
 #	define EVENT_TAG	1
@@ -822,38 +959,24 @@ static int	vmware_service_get_event_data(const zbx_vmware_service_t *service, CU
 #	define LAST_KEY(evs)	(evs->values[evs->values_num - 1]->key)
 
 	char		*event_session = NULL, *err = NULL;
-	int		ret = FAIL, node_count = 1, soap_retry = ATTEMPTS_NUM,
+	int		ret = FAIL, parsed_count = -1, node_count = -1, soap_retry = ATTEMPTS_NUM,
 			soap_count = 5; /* 10 - initial value of eventlog records number in one response */
 	xmlDoc		*doc = NULL;
-	zbx_uint64_t	eventlog_last_key;
-	time_t		eventlog_last_ts;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s()", __func__);
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s() shmem_free_sz:" ZBX_FS_UI64, __func__, shmem_free_sz);
 
-	if (SUCCEED != vmware_service_get_event_session(service, easyhandle, &event_session, error))
+	if (SUCCEED != vmware_service_get_event_session(service, easyhandle, evt_severity, &event_session, error))
 		goto out;
 
 	if (SUCCEED != vmware_service_reset_event_history_collector(easyhandle, event_session, error))
 		goto end_session;
 
-	if (NULL != service->eventlog.data && 0 != service->eventlog.data->events.values_num &&
-			service->eventlog.data->events.values[0]->key > last_key)
-	{
-		eventlog_last_key = service->eventlog.data->events.values[0]->key;
-		eventlog_last_ts = service->eventlog.data->events.values[0]->timestamp;
-	}
-	else
-	{
-		eventlog_last_key = last_key;
-		eventlog_last_ts = last_ts;
-	}
-
 	if (SUCCEED != vmware_service_get_event_latestpage(service, easyhandle, event_session, &doc, error))
 		goto end_session;
 
-	if (0 < vmware_service_parse_event_data(events, eventlog_last_key, eventlog_last_ts, EVENT_TAG, doc,
-			&service->eventlog, alloc_sz, NULL, skip_old) &&
-			(0 != *skip_old || LAST_KEY(events) == eventlog_last_key + 1))
+	if (0 < vmware_service_parse_event_data(events, last_key, last_ts, EVENT_TAG, doc,
+			&service->eventlog, evt_severity, strpool_sz, NULL, skip_old) &&
+			(0 != *skip_old || LAST_KEY(events) == last_key + 1))
 	{
 		zabbix_log(LOG_LEVEL_TRACE, "%s() latestPage events:%d", __func__, events->values_num);
 
@@ -863,17 +986,16 @@ static int	vmware_service_get_event_data(const zbx_vmware_service_t *service, CU
 
 	do
 	{
-		zbx_xml_free_doc(doc);
-		doc = NULL;
+		zbx_xml_doc_free(doc);
 
 		if ((ZBX_MAXQUERYMETRICS_UNLIMITED / 2) >= soap_count)
 			soap_count = soap_count * 2;
 		else if (ZBX_MAXQUERYMETRICS_UNLIMITED != soap_count)
 			soap_count = ZBX_MAXQUERYMETRICS_UNLIMITED;
 
-		if (0 != events->values_num && (LAST_KEY(events) - eventlog_last_key -1) < (unsigned int)soap_count)
+		if (0 != events->values_num && (LAST_KEY(events) - last_key - 1) < (unsigned int)soap_count)
 		{
-			soap_count = (int)(LAST_KEY(events) - eventlog_last_key - 1);
+			soap_count = (int)(LAST_KEY(events) - last_key - 1);
 		}
 
 		if (!ZBX_IS_RUNNING() || (0 < soap_count && SUCCEED != vmware_service_read_previous_events(easyhandle,
@@ -882,17 +1004,29 @@ static int	vmware_service_get_event_data(const zbx_vmware_service_t *service, CU
 			goto end_session;
 		}
 
-		if (0 != node_count)
+		if (0 != node_count && soap_retry != ATTEMPTS_NUM)
 			soap_retry = ATTEMPTS_NUM;
-	}
-	while ((0 < vmware_service_parse_event_data(events, eventlog_last_key, eventlog_last_ts, RETURNVAL_TAG, doc,
-			&service->eventlog, alloc_sz, &node_count, skip_old) ||
-			(0 == node_count && 0 < soap_retry--)) && 0 == *skip_old);
 
-	if (0 != eventlog_last_key && 0 != events->values_num && LAST_KEY(events) != eventlog_last_key + 1)
+		if (shmem_free_sz < *strpool_sz + vmware_service_evt_vector_memsize(events))
+		{
+			vmware_service_clear_event_data_mem(shmem_free_sz, strpool_sz, events);
+
+			if (shmem_free_sz < *strpool_sz + vmware_service_evt_vector_memsize(events))
+				break;
+		}
+	}
+	while ((0 < (parsed_count = vmware_service_parse_event_data(events, last_key, last_ts, RETURNVAL_TAG, doc,
+			&service->eventlog, evt_severity, strpool_sz, &node_count, skip_old)) ||
+			(0 == node_count && 0 < soap_retry--)) && 0 == *skip_old &&
+			(0 == events->values_num || LAST_KEY(events) != last_key + 1));
+
+	if (shmem_free_sz < *strpool_sz + vmware_service_evt_vector_memsize(events))
+		vmware_service_clear_event_data_mem(shmem_free_sz, strpool_sz, events);
+
+	if (0 != last_key && 0 != events->values_num && LAST_KEY(events) != last_key + 1)
 	{
 		zabbix_log(LOG_LEVEL_DEBUG, "%s() events:%d id gap:%d", __func__, events->values_num,
-				(int)(LAST_KEY(events) - (eventlog_last_key + 1)));
+				(int)(LAST_KEY(events) - (last_key + 1)));
 	}
 
 	ret = SUCCEED;
@@ -905,12 +1039,14 @@ end_session:
 	}
 out:
 	zbx_free(event_session);
-	zbx_xml_free_doc(doc);
+	zbx_xml_doc_free(doc);
 
-	if (SUCCEED == ret && 10 == soap_count && 0 == events->values_num && 0 == *skip_old)
+	if (SUCCEED == ret && 10 == soap_count && 0 == events->values_num && 0 == *skip_old && 0 == evt_severity)
 		zabbix_log(LOG_LEVEL_WARNING, "vmware events collector returned empty result");
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s events:%d", __func__, zbx_result_string(ret), events->values_num);
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s events:%d skip_old:%hhu memory:" ZBX_FS_UI64, __func__,
+			zbx_result_string(ret), events->values_num, *skip_old,
+			*strpool_sz + vmware_service_evt_vector_memsize(events));
 
 	return ret;
 
@@ -925,7 +1061,7 @@ out:
  * Parameters: service    - [IN] vmware service                               *
  *             easyhandle - [IN] CURL handle                                  *
  *             events     - [OUT] pointer to output variable                  *
- *             alloc_sz   - [OUT] allocated memory size for events            *
+ *             strpool_sz - [OUT] allocated memory size for events            *
  *             error      - [OUT] error message in case of failure            *
  *                                                                            *
  * Return value: SUCCEED - operation has completed successfully               *
@@ -933,7 +1069,7 @@ out:
  *                                                                            *
  ******************************************************************************/
 static int	vmware_service_get_last_event_data(const zbx_vmware_service_t *service, CURL *easyhandle,
-		zbx_vector_vmware_event_ptr_t *events, zbx_uint64_t *alloc_sz, char **error)
+		zbx_vector_vmware_event_ptr_t *events, zbx_uint64_t *strpool_sz, char **error)
 {
 #	define ZBX_POST_VMWARE_LASTEVENT 								\
 		ZBX_POST_VSPHERE_HEADER									\
@@ -1005,7 +1141,7 @@ static int	vmware_service_get_last_event_data(const zbx_vmware_service_t *servic
 	xml_event.created_time = vmware_service_parse_event_ts(doc, xpathObj->nodesetval->nodeTab[0], xml_event.id);
 
 	if (SUCCEED != vmware_service_put_event_data(events, xml_event, doc, &service->eventlog.evt_severities,
-			alloc_sz))
+			strpool_sz))
 	{
 		*error = zbx_dsprintf(*error, "Cannot retrieve last eventlog data for key "ZBX_FS_UI64, xml_event.id);
 		goto clean;
@@ -1016,7 +1152,7 @@ clean:
 	xmlXPathFreeObject(xpathObj);
 	xmlXPathFreeContext(xpathCtx);
 out:
-	zbx_xml_free_doc(doc);
+	zbx_xml_doc_free(doc);
 	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s last_key:" ZBX_FS_UI64, __func__, zbx_result_string(ret),
 			(SUCCEED == ret ? xml_event.id : 0));
 	return ret;
@@ -1056,13 +1192,12 @@ int	zbx_vmware_service_eventlog_update(zbx_vmware_service_t *service, const char
 	CURL				*easyhandle = NULL;
 	struct curl_slist		*headers = NULL;
 	zbx_vmware_eventlog_data_t	*evt_data;
-	zbx_vector_vmware_event_ptr_t	events;
 	int				ret = FAIL;
 	ZBX_HTTPPAGE			page;	/* 347K/87K */
-	unsigned char			evt_pause = 0, evt_skip_old;
-	zbx_uint64_t			evt_last_key, events_sz = 0;
+	unsigned char			evt_pause = 0, evt_skip_old, evt_severity;
+	zbx_uint64_t			evt_last_key, events_sz = 0, shmem_free_sz = 0;
 	time_t				evt_last_ts;
-	char				msg[MAX_STRING_LEN / 8];
+	char				msg[VMWARE_SHORT_STR_LEN];
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s() '%s'@'%s'", __func__, service->username, service->url);
 
@@ -1071,12 +1206,72 @@ int	zbx_vmware_service_eventlog_update(zbx_vmware_service_t *service, const char
 	zbx_vector_vmware_event_ptr_create(&evt_data->events);
 	page.alloc = 0;
 
+	evt_msg_strpool_init();
+
 	zbx_vmware_lock();
 	evt_last_key = service->eventlog.last_key;
 	evt_skip_old = service->eventlog.skip_old;
 	evt_last_ts = service->eventlog.last_ts;
+	evt_severity = service->eventlog.severity;
+
+	if (NULL != service->eventlog.data && 0 != service->eventlog.data->events.values_num && 0 == evt_skip_old &&
+			service->eventlog.data->events.values[0]->key > evt_last_key)
+	{
+		evt_pause = 1;
+	}
+	else
+	{
+		if (NULL != service->eventlog.data)
+			vmware_eventlog_msg_shared_free(&service->eventlog.data->events);
+
+		if (vmware_shmem_get_vmware_mem()->free_size > vmware_shmem_get_vmware_mem()->total_size * 5 / 100)
+		{
+			shmem_free_sz = vmware_shmem_get_vmware_mem()->free_size -
+					vmware_shmem_get_vmware_mem()->total_size * 5 / 100;
+
+			/* we read events small 1MB (13.5k events) chunks because: */
+			/* - easy for poller */
+			/* - getting data in UI faster */
+			/* - more predictable memory split across multiple VC */
+			/* - memory fragmentation: no need for one monotonic huge chunk of memory */
+			if (shmem_free_sz > ZBX_MEBIBYTE)
+				shmem_free_sz = ZBX_MEBIBYTE;
+
+			service->eventlog.req_sz = 0;
+
+			if (FAIL == vmware_shared_is_ready())
+				evt_pause = 1;
+		}
+		else
+		{
+			evt_pause = 1;
+			service->eventlog.oom = 1;
+		}
+	}
+
 	zbx_vmware_unlock();
 
+	if (0 != evt_pause)
+	{
+		if (0 != service->eventlog.req_sz)
+		{
+			zabbix_log(LOG_LEVEL_WARNING, "Postponed VMware events requires up to " ZBX_FS_UI64
+					" bytes of free VMwareCache memory. Available " ZBX_FS_UI64 " bytes."
+					" Reading events skipped", service->eventlog.req_sz, shmem_free_sz);
+		}
+		else if (0 != service->eventlog.oom)
+		{
+			zabbix_log(LOG_LEVEL_DEBUG, "There is no 5% free memory. Reading new events skipped");
+		}
+		else
+		{
+			zabbix_log(LOG_LEVEL_DEBUG, "Previous events have not been read. Reading new events skipped");
+		}
+
+		ret = SUCCEED;
+		goto out;
+	}
+
 	if (NULL == (easyhandle = curl_easy_init()))
 	{
 		zabbix_log(LOG_LEVEL_WARNING, "Cannot initialize cURL library");
@@ -1095,46 +1290,29 @@ int	zbx_vmware_service_eventlog_update(zbx_vmware_service_t *service, const char
 		goto clean;
 	}
 
-	if (NULL != service->eventlog.data && 0 != service->eventlog.data->events.values_num && 0 == evt_skip_old &&
-			service->eventlog.data->events.values[0]->key > evt_last_key)
+	/* skip collection of event data if we don't know where	*/
+	/* we stopped last time or item can't accept values 	*/
+	if (ZBX_VMWARE_EVENT_KEY_UNINITIALIZED != evt_last_key && 0 == evt_skip_old && 0 != shmem_free_sz &&
+			SUCCEED != vmware_service_get_event_data(service, easyhandle, evt_last_key, evt_last_ts,
+			shmem_free_sz, evt_severity, &evt_skip_old, &evt_data->events, &events_sz,
+			&evt_data->error))
 	{
-		evt_pause = 1;
+		goto clean;
 	}
 
-	if (0 == service->eventlog.req_sz && 0 == evt_pause)
+	if (0 != evt_skip_old)
 	{
-		/* skip collection of event data if we don't know where	*/
-		/* we stopped last time or item can't accept values 	*/
-		if (ZBX_VMWARE_EVENT_KEY_UNINITIALIZED != evt_last_key && 0 == evt_skip_old &&
-				SUCCEED != vmware_service_get_event_data(service, easyhandle, evt_last_key, evt_last_ts,
-				&evt_skip_old, &evt_data->events, &events_sz, &evt_data->error))
+		char	*error = NULL;
+
+		/* May not be present */
+		if (SUCCEED != vmware_service_get_last_event_data(service, easyhandle, &evt_data->events,
+				&events_sz, &error))
 		{
-			goto clean;
+			zabbix_log(LOG_LEVEL_DEBUG, "Unable retrieve lastevent value: %s.", error);
+			zbx_free(error);
 		}
-
-		if (0 != evt_skip_old)
-		{
-			char	*error = NULL;
-
-			/* May not be present */
-			if (SUCCEED != vmware_service_get_last_event_data(service, easyhandle, &evt_data->events,
-					&events_sz, &error))
-			{
-				zabbix_log(LOG_LEVEL_DEBUG, "Unable retrieve lastevent value: %s.", error);
-				zbx_free(error);
-			}
-			else
-				evt_skip_old = 0;
-		}
-	}
-	else if (0 != service->eventlog.req_sz)
-	{
-		zabbix_log(LOG_LEVEL_WARNING, "Postponed VMware events requires up to " ZBX_FS_UI64
-				" bytes of free VMwareCache memory. Reading events skipped", service->eventlog.req_sz);
-	}
-	else
-	{
-		zabbix_log(LOG_LEVEL_DEBUG, "Previous events have not been read. Reading new events skipped");
+		else
+			evt_skip_old = 0;
 	}
 
 	if (SUCCEED != vmware_service_logout(service, easyhandle, &evt_data->error))
@@ -1149,7 +1327,6 @@ clean:
 	curl_easy_cleanup(easyhandle);
 	zbx_free(page.data);
 out:
-	zbx_vector_vmware_event_ptr_create(&events);
 	zbx_vmware_lock();
 
 	if (0 < evt_data->events.values_num)
@@ -1157,23 +1334,12 @@ out:
 		if (0 != service->eventlog.oom)
 			service->eventlog.oom = 0;
 
-		events_sz += zbx_vmware_get_evt_req_chunk_sz() * evt_data->events.values_num +
-				zbx_shmem_required_chunk_size(evt_data->events.values_alloc *
-				sizeof(zbx_vmware_event_t*));
+		events_sz += vmware_service_evt_vector_memsize(&evt_data->events);
 
 		if (0 == service->eventlog.last_key || vmware_shmem_get_vmware_mem()->free_size < events_sz ||
 				SUCCEED == ZBX_CHECK_LOG_LEVEL(LOG_LEVEL_DEBUG))
 		{
-			for (int i = 0; i < evt_data->events.values_num; i++)
-			{
-				zbx_vmware_event_t	*event = evt_data->events.values[i];
-
-				if (SUCCEED == vmware_shared_strsearch(event->message))
-				{
-					events_sz -= zbx_shmem_required_chunk_size(strlen(event->message) +
-							REFCOUNT_FIELD_SIZE + 1 + ZBX_HASHSET_ENTRY_OFFSET);
-				}
-			}
+			events_sz -= vmware_evt_strpool_overlap_mem();
 
 			if (vmware_shmem_get_vmware_mem()->free_size < events_sz)
 			{
@@ -1190,7 +1356,7 @@ out:
 						zbx_vmware_get_vmware()->strpool_sz,
 						vmware_shmem_get_vmware_mem()->total_size);
 			}
-			else if (0 == evt_pause)
+			else
 			{
 				int	level;
 
@@ -1205,28 +1371,12 @@ out:
 			}
 		}
 	}
-	else if (0 < service->eventlog.req_sz && service->eventlog.req_sz <= vmware_shmem_get_vmware_mem()->free_size)
-	{
-		service->eventlog.req_sz = 0;
-	}
 
-	if (0 != evt_pause)
+	if (0 == evt_pause)
 	{
-		zbx_vector_vmware_event_ptr_append_array(&events, service->eventlog.data->events.values,
-				service->eventlog.data->events.values_num);
-		zbx_vector_vmware_event_ptr_reserve(&evt_data->events,
-				(size_t)(evt_data->events.values_num + service->eventlog.data->events.values_num));
-		zbx_vector_vmware_event_ptr_clear(&service->eventlog.data->events);
-	}
-
-	vmware_eventlog_data_shared_free(service->eventlog.data);
-	service->eventlog.data = vmware_shmem_eventlog_data_dup(evt_data);
-	service->eventlog.skip_old = evt_skip_old;
-
-	if (0 != events.values_num)
-	{
-		zbx_vector_vmware_event_ptr_append_array(&service->eventlog.data->events, events.values,
-				events.values_num);
+		vmware_eventlog_data_shared_free(service->eventlog.data);
+		service->eventlog.data = vmware_shmem_eventlog_data_dup(evt_data);
+		service->eventlog.skip_old = evt_skip_old;
 	}
 
 	if (SUCCEED == ZBX_CHECK_LOG_LEVEL(LOG_LEVEL_DEBUG))
@@ -1241,7 +1391,7 @@ out:
 	zbx_vmware_unlock();
 
 	vmware_eventlog_data_free(evt_data);
-	zbx_vector_vmware_event_ptr_destroy(&events);
+	evt_msg_strpool_destroy();
 
 	zabbix_log(LOG_LEVEL_DEBUG, "End of %s():%s \tprocessed:" ZBX_FS_SIZE_T " bytes of data. %s", __func__,
 			zbx_result_string(ret), (zbx_fs_size_t)page.alloc, msg);
