@@ -68,6 +68,7 @@ static zbx_vmware_job_t	*vmware_job_get(zbx_vmware_t *vmw, time_t time_now)
 	zbx_binary_heap_elem_t	*elem;
 	zbx_vmware_job_t	*job = NULL;
 	time_t			lastaccess;
+	int			revision;
 
 	zabbix_log(LOG_LEVEL_DEBUG, "In %s() queue:%d", __func__, vmw->jobs_queue.elems_num);
 
@@ -89,8 +90,9 @@ static zbx_vmware_job_t	*vmware_job_get(zbx_vmware_t *vmw, time_t time_now)
 	job->nextcheck = 0;
 	lastaccess = (ZBX_VMWARE_UPDATE_EVENTLOG == job->type) ? job->service->eventlog.lastaccess :
 			job->service->lastaccess;
+	revision = (ZBX_VMWARE_UPDATE_EVENTLOG == job->type) ? job->service->eventlog.job_revision : 0;
 
-	if (0 != lastaccess && 0 != job->ttl && time_now - lastaccess > job->ttl)
+	if ((0 != lastaccess && 0 != job->ttl && time_now - lastaccess > job->ttl) || job->revision != revision)
 	{
 		job->expired = SUCCEED;
 	}
@@ -119,7 +121,8 @@ static int	vmware_job_exec(zbx_vmware_job_t *job, const char *config_source_ip,
 {
 	int	ret = FAIL;
 
-	zabbix_log(LOG_LEVEL_DEBUG, "In %s() type:%s", __func__, vmware_job_type_string(job));
+	zabbix_log(LOG_LEVEL_DEBUG, "In %s() type:%s revision:%d", __func__, vmware_job_type_string(job),
+			job->revision);
 
 	if (ZBX_VMWARE_UPDATE_CONF != job->type && 0 == (job->service->state & ZBX_VMWARE_STATE_READY))
 		goto out;
@@ -194,20 +197,24 @@ static void	vmware_job_schedule(zbx_vmware_t *vmw, zbx_vmware_job_t *job, time_t
 			job->nextcheck = time_now + cache_update_period;
 			break;
 		case ZBX_VMWARE_UPDATE_EVENTLOG:
-			if (0 == job->ttl)
-				job->ttl = cache_update_period * 2;
+			job->ttl = 2 * (0 != job->service->eventlog.interval ?
+					job->service->eventlog.interval : perf_update_period) +
+					ZBX_VMWARE_EVENTLOG_MIN_INTERVAL;
 
 			job->nextcheck = time_now + (0 == job->service->eventlog.interval ? perf_update_period :
 					(ZBX_VMWARE_EVENTLOG_MIN_INTERVAL > job->service->eventlog.interval ?
 					ZBX_VMWARE_EVENTLOG_MIN_INTERVAL : job->service->eventlog.interval));
+
+			if (job->nextcheck > time_now + ZBX_VMWARE_SERVICE_TTL)
+				job->nextcheck = time_now + ZBX_VMWARE_SERVICE_TTL;
 			break;
 	}
 
 	zbx_binary_heap_insert(&vmw->jobs_queue, &elem_new);
 	zbx_vmware_unlock();
 
-	zabbix_log(LOG_LEVEL_DEBUG, "End of %s() type:%s nextcheck:%s", __func__, vmware_job_type_string(job),
-			zbx_time2str(job->nextcheck, NULL));
+	zabbix_log(LOG_LEVEL_DEBUG, "End of %s() type:%s nextcheck:%s ttl:" ZBX_FS_TIME_T, __func__,
+			vmware_job_type_string(job), zbx_time2str(job->nextcheck, NULL), job->ttl);
 
 #undef ZBX_VMWARE_EVENTLOG_MIN_INTERVAL
 #undef ZBX_VMWARE_SERVICE_TTL
