@@ -118,11 +118,15 @@ class CControllerItemList extends CControllerItem {
 		[$items, $subfilter_fields] = $this->getItemsAndSubfilter($items, $this->getSubfilter($items, $filter));
 		$data['subfilter'] = static::sortSubfilter($subfilter_fields);
 		$items = $this->sortItems($items, ['sort' => $filter['sort'], 'sortorder' => $filter['sortorder']]);
-		$data['paging'] = CPagerHelper::paginate($page, $items, $filter['sortorder'],
-			(new CUrl('zabbix.php'))
-				->setArgument('action', $data['action'])
-				->setArgument('context', $data['context'])
-		);
+
+		$selected_filters = array_merge($filter, $this->getselectedSubfilters($subfilter_fields));
+		$view_url = new CUrl('zabbix.php');
+		$view_url_params = ['action' => $data['action'], 'context' => $data['context']] + $selected_filters;
+
+		array_map([$view_url, 'setArgument'], array_keys($view_url_params), $view_url_params);
+
+		$data['paging'] = CPagerHelper::paginate($page, $items, $filter['sortorder'], $view_url);
+
 		$triggers = $this->getItemsTriggers($items);
 
 		if (count($filter['filter_hostids']) == 1) {
@@ -150,6 +154,23 @@ class CControllerItemList extends CControllerItem {
 		$this->setResponse($response);
 	}
 
+	/**
+	 * @param array $subfilters  Array of subfilter data.
+	 *
+	 * @return array
+	 */
+	private function getselectedSubfilters($subfilters): array {
+		$result = [];
+
+		foreach ($subfilters as $key => $subfilter) {
+			if ($subfilter['selected']) {
+				$result[$key] = array_keys($subfilter['selected']);
+			}
+		}
+
+		return $result;
+	}
+
 	/**
 	 * Sorts array [values] in ascending order based on entries in [sort] array.
 	 * If [sort] does not have an entry for sorting, the [labels] array value is used.
@@ -708,7 +729,7 @@ class CControllerItemList extends CControllerItem {
 				'subfilter_inherited' => [$item['templateid'] > 0 ? 1 : 0],
 				'subfilter_with_triggers' => [count($item['triggers']) > 0 ? 1 : 0],
 				'subfilter_history' => [$item['history']],
-				'subfilter_state' => [$item['state']],
+				'subfilter_state' => $item['status'] == ITEM_STATUS_ACTIVE ? [$item['state']] : [],
 				'subfilter_discovered' => [$item['flags'] == ZBX_FLAG_DISCOVERY_CREATED ? 1 : 0],
 				'subfilter_trends' => [],
 				'subfilter_interval' => [],
