@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -24,7 +19,7 @@ require_once dirname(__FILE__).'/../../include/forms.inc.php';
 class CControllerPopupLldOperation extends CController {
 
 	protected function init() {
-		$this->disableSIDvalidation();
+		$this->disableCsrfValidation();
 	}
 
 	protected function checkInput() {
@@ -50,13 +45,12 @@ class CControllerPopupLldOperation extends CController {
 		$ret = $this->validateInput($fields);
 
 		if (!$ret) {
-			$output = [];
-			if (($messages = getMessages()) !== null) {
-				$output['errors'] = $messages->toString();
-			}
-
 			$this->setResponse(
-				(new CControllerResponseData(['main_block' => json_encode($output)]))->disableView()
+				(new CControllerResponseData(['main_block' => json_encode([
+					'error' => [
+						'messages' => array_column(get_and_clear_messages(), 'message')
+					]
+				])]))->disableView()
 			);
 		}
 
@@ -216,7 +210,7 @@ class CControllerPopupLldOperation extends CController {
 					&& $page_options['ophistory']['history_mode'] == ITEM_STORAGE_CUSTOM
 					&& !validateTimeUnit($page_options['ophistory']['history'], SEC_PER_HOUR, 25 * SEC_PER_YEAR, true,
 						$error, ['usermacros' => true, 'lldmacros' => true])) {
-				error(_s('Incorrect value for field "%1$s": %2$s.', _('History storage period'), $error));
+				error(_s('Incorrect value for field "%1$s": %2$s.', _('History'), $error));
 			}
 
 			if (array_key_exists('optrends', $page_options)
@@ -224,12 +218,12 @@ class CControllerPopupLldOperation extends CController {
 					&& $page_options['optrends']['trends_mode'] == ITEM_STORAGE_CUSTOM
 					&& !validateTimeUnit($page_options['optrends']['trends'], SEC_PER_DAY, 25 * SEC_PER_YEAR, true,
 						$error, ['usermacros' => true, 'lldmacros' => true])) {
-				error(_s('Incorrect value for field "%1$s": %2$s.', _('Trend storage period'), $error));
+				error(_s('Incorrect value for field "%1$s": %2$s.', _('Trends'), $error));
 			}
 
 			// Return collected error messages.
-			if (($messages = getMessages()) !== null) {
-				$output['errors'] = $messages->toString();
+			if ($messages = get_and_clear_messages()) {
+				$output['error']['messages'] = array_column($messages, 'message');
 			}
 			else {
 				// Return valid response.
