@@ -41,6 +41,10 @@ class CAlert extends CApiService {
 	 * @return array|string
 	 */
 	public function get(array $options = []) {
+		$mediatype_output_fields = self::$userData['type'] == USER_TYPE_SUPER_ADMIN
+			? CMediatype::OUTPUT_FIELDS
+			: CMediatype::LIMITED_OUTPUT_FIELDS;
+
 		$api_input_rules = ['type' => API_OBJECT, 'fields' => [
 			// filter
 			'alertids' =>				['type' => API_IDS, 'flags' => API_ALLOW_NULL | API_NORMALIZE, 'default' => null],
@@ -60,7 +64,7 @@ class CAlert extends CApiService {
 			'countOutput' =>			['type' => API_FLAG, 'default' => false],
 			'groupCount' =>				['type' => API_FLAG, 'default' => false],
 			'selectHosts' =>			['type' => API_OUTPUT, 'flags' => API_ALLOW_NULL, 'in' => implode(',', CHost::OUTPUT_FIELDS), 'default' => null],
-			'selectMediatypes' =>		['type' => API_OUTPUT, 'flags' => API_ALLOW_NULL, 'in' => implode(',', CMediatype::OUTPUT_FIELDS), 'default' => null],
+			'selectMediatypes' =>		['type' => API_OUTPUT, 'flags' => API_ALLOW_NULL, 'in' => implode(',', $mediatype_output_fields), 'default' => null],
 			'selectUsers' =>			['type' => API_OUTPUT, 'flags' => API_ALLOW_NULL, 'in' => implode(',', CUser::OUTPUT_FIELDS), 'default' => null],
 			'filter' =>					['type' => API_FILTER, 'flags' => API_ALLOW_NULL, 'default' => null, 'fields' => ['alertid', 'actionid', 'eventid', 'userid', 'mediatypeid', 'status', 'acknowledgeid']],
 			'search' =>					['type' => API_FILTER, 'flags' => API_ALLOW_NULL, 'default' => null, 'fields' => ['sendto', 'subject', 'message', 'error']],
@@ -181,7 +185,7 @@ class CAlert extends CApiService {
 		if (self::$userData['type'] != USER_TYPE_SUPER_ADMIN && !$options['nopermissions']) {
 			if ($options['eventobject'] == EVENT_OBJECT_TRIGGER) {
 				if (self::$userData['ugsetid'] == 0) {
-					return $options['countOutput'] ? '0' : [];
+					$sql_parts['where'][] = '1=0';
 				}
 
 				$sql_parts['from']['e'] = 'events e';
@@ -213,7 +217,7 @@ class CAlert extends CApiService {
 			}
 			elseif (in_array($options['eventobject'], [EVENT_OBJECT_ITEM, EVENT_OBJECT_LLDRULE])) {
 				if (self::$userData['ugsetid'] == 0) {
-					return $options['countOutput'] ? '0' : [];
+					$sql_parts['where'][] = '1=0';
 				}
 
 				$sql_parts['from']['e'] = 'events e';
@@ -431,7 +435,7 @@ class CAlert extends CApiService {
 
 		$relation_map = $this->createRelationMap($result, 'alertid', 'mediatypeid');
 
-		$mediatypes = API::getApiService()->select('media_type', [
+		$mediatypes = API::MediaType()->get([
 			'output' => $options['selectMediatypes'],
 			'filter' => ['mediatypeid' => $relation_map->getRelatedIds()],
 			'preservekeys' => true
