@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2025 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -25,10 +20,16 @@ class CButtonQMessage extends CSubmit {
 	public $msg;
 	public $name;
 
-	public function __construct($name, $caption, $msg = null, $vars = null) {
+	/**
+	 * @var string  An URL parameter to be left in URL after redirect.
+	 */
+	private $url_param_exclude;
+
+	public function __construct($name, $caption, $msg = null, $vars = null, $url_param_exclude = '') {
 		$this->vars = null;
 		$this->msg = null;
 		$this->name = $name;
+		$this->url_param_exclude = $url_param_exclude;
 		parent::__construct($name, $caption);
 		$this->setMessage($msg);
 		$this->setVars($vars);
@@ -43,7 +44,7 @@ class CButtonQMessage extends CSubmit {
 
 	public function setMessage($value = null) {
 		if (is_null($value)) {
-			$value = _('Are you sure you want perform this action?');
+			$value = _('Are you sure you want to perform this action?');
 		}
 		// if message will contain single quotes, it will break everything, so it must be escaped
 		$this->msg = zbx_jsvalue(
@@ -62,16 +63,21 @@ class CButtonQMessage extends CSubmit {
 		}
 
 		global $page;
+
 		$confirmation = "Confirm('".$this->msg."')";
 
 		if (isset($this->vars)) {
 			$link = $page['file'].'?'.$this->name.'=1'.$this->vars;
-			$action = "redirect('".(new CUrl($link))->getUrl()."', 'post')";
+			$action = "redirect('".(new CUrl($link))->getUrl()."', 'post'".
+				(($this->url_param_exclude !== '') ? ", '".$this->url_param_exclude."'" : "").
+			")";
 		}
 		else {
 			$action = 'true';
 		}
+
 		parent::onClick('if ('.$confirmation.') { return '.$action.'; } else { return false; }');
+
 		return $this;
 	}
 }
