@@ -555,7 +555,7 @@ class WidgetView extends CControllerDashboardWidgetView {
 
 		$total_value['value'] = $raw_total_value;
 
-		if ($raw_total_value !== null && $raw_total_value !== 0) {
+		if ($raw_total_value !== null) {
 			$total_value['formatted_value'] = $formatted_total_value;
 		}
 	}
@@ -640,7 +640,7 @@ class WidgetView extends CControllerDashboardWidgetView {
 	}
 
 	private function getSVGData(array $sectors, array $total_value): array {
-		if ($total_value['value'] === null || $total_value['value'] === 0) {
+		if ($total_value['value'] === null) {
 			return [
 				'svg_sectors' => [],
 				'svg_total_value' => $total_value
@@ -651,8 +651,8 @@ class WidgetView extends CControllerDashboardWidgetView {
 		$non_total_sectors = [];
 		$has_total_item = false;
 
-		$sectors = array_filter($sectors, function ($sector) {
-			return $sector['value'] != 0;
+		$sectors = array_filter($sectors, static function ($sector) {
+			return $sector['value'] !== null;
 		});
 
 		// Move total sector to the end.
@@ -668,7 +668,12 @@ class WidgetView extends CControllerDashboardWidgetView {
 		$svg_sectors = array_values($sectors);
 
 		foreach ($svg_sectors as &$sector) {
-			$sector['percent_of_total'] = (abs($sector['value']) / $total_value['value']) * 100;
+			if ($total_value['value']) {
+				$sector['percent_of_total'] = (abs($sector['value']) / $total_value['value']) * 100;
+			}
+			else {
+				$sector['percent_of_total'] = 0;
+			}
 
 			if (!$sector['is_total']) {
 				$sector_total_value += abs($sector['value']);
@@ -724,7 +729,7 @@ class WidgetView extends CControllerDashboardWidgetView {
 
 		return [
 			'svg_sectors' => $svg_sectors,
-			'svg_total_value' => $total_value['formatted_value']
+			'svg_total_value' => $total_value
 		];
 	}
 }
